"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
// Angular Material
var material_1 = require("@angular/material");
// Fullscreen Service
var angular_bigscreen_1 = require("angular-bigscreen");
var openvidu_directive_1 = require("../openvidu.directive");
// i18n Labels and Messages
var openvidu_appearin_intl_1 = require("./openvidu-appearin-intl");
var ConnectionState;
(function (ConnectionState) {
    ConnectionState[ConnectionState["NOT_CONNECTED"] = 0] = "NOT_CONNECTED";
    ConnectionState[ConnectionState["CONNECTED_TO_SERVER"] = 1] = "CONNECTED_TO_SERVER";
    ConnectionState[ConnectionState["CONNECTED_TO_ROOM"] = 2] = "CONNECTED_TO_ROOM";
    ConnectionState[ConnectionState["REQUESTING_CAMERA_ACCESS"] = 3] = "REQUESTING_CAMERA_ACCESS";
    ConnectionState[ConnectionState["CAMERA_ACCESS_GRANTED"] = 4] = "CAMERA_ACCESS_GRANTED";
    ConnectionState[ConnectionState["CAMERA_ACCESS_DENIED"] = 5] = "CAMERA_ACCESS_DENIED";
})(ConnectionState = exports.ConnectionState || (exports.ConnectionState = {}));
;
var OpenViduAppearinComponent = (function () {
    function OpenViduAppearinComponent(renderer, bigScreenService, _intl) {
        this.renderer = renderer;
        this.bigScreenService = bigScreenService;
        this._intl = _intl;
        // Unique Inputs
        // To set new options in menu
        this.toolbarOptions = [];
        // Outputs
        this.onRoomConnected = new core_1.EventEmitter();
        this.onErrorRoom = new core_1.EventEmitter();
        this.onRoomClosed = new core_1.EventEmitter();
        this.onLostConnection = new core_1.EventEmitter();
        this.onParticipantJoined = new core_1.EventEmitter();
        this.onParticipantLeft = new core_1.EventEmitter();
        this.onNewMessage = new core_1.EventEmitter();
        this.onErrorMedia = new core_1.EventEmitter();
        this.onLeaveRoom = new core_1.EventEmitter();
        this.onCustomNotification = new core_1.EventEmitter();
        // Responsive streams
        this.streamMaxWidth = '100%';
        this.streamMaxHeight = '100%';
        // Flags for HTML elements
        this.userMessage = '';
        this.isFullscreen = false;
        this.welcome = true;
        this.showChat = false;
        // Rest of peers
        this.streams = [];
        // Chat
        this.chatMessages = [];
        // Animations
        this.chatButtonState = 'show';
        // Connection stats
        this.ConnectionState = ConnectionState;
        this.connectionUiState = ConnectionState.NOT_CONNECTED;
        // Participants
        this.participants = {};
        this.welcome = true;
        this.setUserMessage(this._intl.loadingLabel);
    }
    OpenViduAppearinComponent.prototype.ngOnInit = function () {
        var _this = this;
        // Display message
        this.setUserMessage(this._intl.connectingLabel);
        // Set fullscreen listener
        this.bigScreenService.onChange(function () {
            // No need to check if mainElement is the one with fullscreen
            _this.isFullscreen = _this.bigScreenService.isFullscreen();
            // Fix: Resize videos
            setTimeout(function () {
                _this.resizeStreamsManually();
            }, 1000);
        });
    };
    OpenViduAppearinComponent.prototype.ngOnDestroy = function () {
        this.bigScreenService.exit();
        this.leaveRoom();
    };
    /*---------------------*/
    /* GUI RELATED METHODS */
    /*---------------------*/
    OpenViduAppearinComponent.prototype.onResize = function (event) {
        //this.resizeStreamsManually();
    };
    OpenViduAppearinComponent.prototype.toggleMic = function () {
        this.openviduApi.micEnabled = !this.openviduApi.micEnabled;
    };
    OpenViduAppearinComponent.prototype.toggleCamera = function () {
        this.openviduApi.camEnabled = !this.openviduApi.camEnabled;
    };
    OpenViduAppearinComponent.prototype.toggleFullscreen = function () {
        if (this.bigScreenService.isFullscreen()) {
            this.bigScreenService.exit();
        }
        else {
            this.bigScreenService.request(this.mainElement.nativeElement);
        }
    };
    OpenViduAppearinComponent.prototype.toggleChat = function () {
        //this.sidenav.toggle();
        this.showChat = !this.showChat;
    };
    OpenViduAppearinComponent.prototype.onSidenavOpenStart = function () {
        // TODO: Retrive chats
        this.chatButtonState = 'hide';
    };
    OpenViduAppearinComponent.prototype.sendMessage = function (text) {
        // Clean input
        this.messageInput.nativeElement.value = null;
        //this.renderer.setValue(this.messageInput, null);
        // Send to OpenVidu server
        this.openviduApi.sendMessage(text);
    };
    OpenViduAppearinComponent.prototype.sendCustomNotification = function (obj, callback) {
        this.openviduApi.sendCustomNotification(obj, callback);
    };
    OpenViduAppearinComponent.prototype.leaveRoom = function () {
        // Reset
        this.mainStream = null;
        this.streams = [];
        this.chatMessages = [];
        this.chatButtonState = 'show';
        this.session = null;
        this.participants = {};
        // Display message
        this.setUserMessage(this._intl.youLeftTheRoomLabel);
        this.openviduApi.leaveRoom();
    };
    /*------------------------*/
    /* HANDLE OPENVIDU EVENTS */
    /*------------------------*/
    OpenViduAppearinComponent.prototype.handleOnUpdateMainSpeaker = function (streamEvent) {
        // Check if stream exists
        if (this.streams.indexOf(streamEvent.stream) < 0) {
            this.streams.push(streamEvent.stream);
        }
        // Set main stream
        this.mainStream = streamEvent.stream;
        // Check if participant exists
        if (!this.participants[this.mainStream.getParticipant().getId()]) {
            this.participants[this.mainStream.getParticipant().getId()] = this.mainStream.getParticipant();
        }
    };
    OpenViduAppearinComponent.prototype.handleOnServerConnected = function () {
        this.setUserMessage(this._intl.connectingToRoomLabel);
        this.connectionUiState = ConnectionState.CONNECTED_TO_SERVER;
    };
    OpenViduAppearinComponent.prototype.handleOnErrorServer = function (errorEvent) {
        if (errorEvent.error) {
            this.setUserMessage(errorEvent.error.message);
        }
    };
    OpenViduAppearinComponent.prototype.handleOnRoomConnected = function (roomConnectedEvent) {
        if (roomConnectedEvent && roomConnectedEvent.session) {
            this.session = roomConnectedEvent.session;
        }
        // Emit event
        this.onRoomConnected.emit();
        this.connectionUiState = ConnectionState.CONNECTED_TO_ROOM;
    };
    OpenViduAppearinComponent.prototype.handleOnErrorRoom = function () {
        this.setUserMessage(this._intl.errorRoom);
        // Emit event
        this.onErrorRoom.emit();
    };
    OpenViduAppearinComponent.prototype.handleOnCameraAccessChange = function (cameraEvent) {
        if (cameraEvent.access) {
            // All good :)
            this.myCamera = cameraEvent.camera;
            if (this.streams.indexOf(this.myCamera) < 0) {
                this.streams.push(this.myCamera);
            }
            this.welcome = false;
            this.connectionUiState = ConnectionState.CAMERA_ACCESS_GRANTED;
        }
        else if (!cameraEvent.access) {
            // No camera :(
            this.connectionUiState = ConnectionState.CAMERA_ACCESS_DENIED;
        }
    };
    OpenViduAppearinComponent.prototype.handleOnRoomClosed = function () {
        this.session = null;
        // Emit event
        this.onRoomClosed.emit();
    };
    OpenViduAppearinComponent.prototype.handleOnLostConnection = function () {
        if (!this.session) {
            // Emit event
            this.onLostConnection.emit({
                error: new Error('Lost connection with the server')
            });
        }
        else {
            // Emit event
            this.onLostConnection.emit();
        }
    };
    OpenViduAppearinComponent.prototype.handleOnParticipantJoined = function (participantEvent) {
        var newParticipant = participantEvent.participant;
        this.participants[newParticipant.getId()] = newParticipant;
        // Emit event
        this.onParticipantJoined.emit({
            participantId: newParticipant.getId()
        });
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduAppearinComponent.prototype.handleOnParticipantLeft = function (participantEvent) {
        var oldParticipant = participantEvent.participant;
        delete this.participants[oldParticipant.getId()];
        // Emit event
        this.onParticipantLeft.emit({
            participantId: oldParticipant.getId()
        });
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduAppearinComponent.prototype.handleOnErrorMedia = function (errorEvent) {
        // Emit event
        this.onErrorMedia.emit({
            error: errorEvent.error
        });
    };
    OpenViduAppearinComponent.prototype.handleOnStreamAdded = function (streamEvent) {
        var newStream = streamEvent.stream;
        if (this.streams.indexOf(newStream) < 0) {
            this.streams.push(newStream);
        }
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduAppearinComponent.prototype.handleOnStreamRemoved = function (streamEvent) {
        var oldStream = streamEvent.stream;
        this.streams.splice(this.streams.indexOf(oldStream), 1);
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduAppearinComponent.prototype.handleOnCustomNotification = function (object) {
        this.onCustomNotification.emit(object);
    };
    OpenViduAppearinComponent.prototype.handleOnLeaveRoom = function () {
        // Emit event
        this.onLeaveRoom.emit();
    };
    OpenViduAppearinComponent.prototype.handleOnNewMessage = function (messageEvent) {
        // Fix: to get usernam
        var dataObj = JSON.parse(messageEvent.participant.data);
        // Handle message
        this.chatMessages.push({
            username: dataObj.username,
            message: messageEvent.message,
            date: new Date() // Use current date
        });
        this.onNewMessage.emit(messageEvent);
    };
    OpenViduAppearinComponent.prototype.handleOnSourceAdded = function () {
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduAppearinComponent.prototype.setUserMessage = function (msg) {
        this.userMessage = msg;
    };
    OpenViduAppearinComponent.prototype.resizeStreamsManually = function () {
        console.log('Resizing...');
        var obj = this.auxResizeStreamsManually();
        //console.log(obj);
        if (!obj.error) {
            this.streamMaxWidth = obj.width + 'px';
            this.streamMaxHeight = obj.height + 'px';
        }
    };
    OpenViduAppearinComponent.prototype.auxResizeStreamsManually = function () {
        if (!this.panelVideo)
            return;
        var clientRect = this.panelVideo.nativeElement.getBoundingClientRect();
        console.log(clientRect);
        var maxDimensions = {
            maxW: 0,
            maxH: 0
        };
        this.streamAppearin.forEach(function (streamGoToMeetingEl) {
            var videoEl = streamGoToMeetingEl.videoStream.nativeElement;
            if (videoEl.videoWidth > maxDimensions.maxW) {
                if (videoEl.videoHeight > maxDimensions.maxH) {
                    maxDimensions.maxW = videoEl.videoWidth;
                    maxDimensions.maxH = videoEl.videoHeight;
                }
            }
        });
        //console.log(maxDimensions);
        var numElements = this.streamAppearin.length;
        var width = clientRect.width;
        var height = clientRect.height;
        var area = height * width;
        var elementArea = parseInt((area / numElements) + '');
        // Calculate proportions
        var maxProportions = {
            maxW: 0,
            maxH: 0,
        };
        if (width > height) {
            // It'a horizontal rectangle
            maxProportions.maxW = maxDimensions.maxW / maxDimensions.maxH;
            maxProportions.maxH = ((maxDimensions.maxW / maxDimensions.maxH) * maxDimensions.maxH) / maxDimensions.maxW;
        }
        else if (height > width) {
            // It'a vertcal rectangle
            maxProportions.maxW = ((maxDimensions.maxH / maxDimensions.maxW) * maxDimensions.maxW) / maxDimensions.maxH;
            maxProportions.maxH = maxDimensions.maxH / maxDimensions.maxW;
        }
        else {
            // It's a square
            maxProportions.maxW = maxDimensions.maxW / maxDimensions.maxH;
            maxProportions.maxH = ((maxDimensions.maxW / maxDimensions.maxH) * maxDimensions.maxH) / maxDimensions.maxW;
        }
        //console.log(maxProportions);
        var elementWidth = parseInt(Math.sqrt(elementArea * (maxProportions.maxW / maxProportions.maxH)) + '');
        var elementHeight = parseInt(Math.sqrt(elementArea * (maxProportions.maxH / maxProportions.maxW)) + '');
        //console.log(elementWidth);
        // We now need to fit the squares. Let's reduce the square size
        // so an integer number fits the width.
        var numX = Math.ceil(width / elementWidth);
        elementWidth = width / numX;
        elementHeight = elementWidth * (maxProportions.maxH / maxProportions.maxW);
        while (numX <= numElements) {
            // With a bit of luck, we are done.
            if (Math.floor(height / elementHeight) * numX >= numElements) {
                // They all fit! We are done!
                return { width: elementWidth, height: elementHeight };
            }
            // They don't fit. Make room for one more square i each row.
            numX++;
            elementWidth = width / numX;
            elementHeight = elementWidth * (maxProportions.maxH / maxProportions.maxW);
        }
        // Still doesn't fit? The window must be very wide
        // and low.
        elementHeight = height;
        return { width: elementWidth, height: elementHeight };
    };
    return OpenViduAppearinComponent;
}());
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduAppearinComponent.prototype, "wsUrl", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduAppearinComponent.prototype, "sessionId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduAppearinComponent.prototype, "participantId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduAppearinComponent.prototype, "apiKey", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduAppearinComponent.prototype, "token", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", Array)
], OpenViduAppearinComponent.prototype, "toolbarOptions", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onRoomConnected", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onErrorRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onRoomClosed", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onLostConnection", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onParticipantJoined", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onParticipantLeft", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onNewMessage", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onErrorMedia", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onLeaveRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduAppearinComponent.prototype, "onCustomNotification", void 0);
__decorate([
    core_1.ViewChild('openviduApi'),
    __metadata("design:type", openvidu_directive_1.OpenViduDirective)
], OpenViduAppearinComponent.prototype, "openviduApi", void 0);
__decorate([
    core_1.ViewChild('main'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduAppearinComponent.prototype, "mainElement", void 0);
__decorate([
    core_1.ViewChild('sidenav'),
    __metadata("design:type", material_1.MdSidenav)
], OpenViduAppearinComponent.prototype, "sidenav", void 0);
__decorate([
    core_1.ViewChild('messageInput'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduAppearinComponent.prototype, "messageInput", void 0);
__decorate([
    core_1.ViewChild('panelVideo'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduAppearinComponent.prototype, "panelVideo", void 0);
__decorate([
    core_1.ViewChildren('streamAppearin'),
    __metadata("design:type", core_1.QueryList)
], OpenViduAppearinComponent.prototype, "streamAppearin", void 0);
__decorate([
    core_1.HostListener('window:resize', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], OpenViduAppearinComponent.prototype, "onResize", null);
OpenViduAppearinComponent = __decorate([
    core_1.Component({
        selector: 'openvidu-appearin',
        template: "\n   <openvidu-template\n   \t#openviduApi=\"openviduApi\"\n   \t[wsUrl]=\"wsUrl\"\n   \t[sessionId]=\"sessionId\"\n   \t[participantId]=\"participantId\"\n\t\n   \t(onUpdateMainSpeaker)=\"handleOnUpdateMainSpeaker($event)\"\n\t\n   \t(onServerConnected)=\"handleOnServerConnected($event)\"\n   \t(onErrorServer)=\"handleOnErrorServer($event)\"\n   \t(onRoomConnected)=\"handleOnRoomConnected($event)\"\n   \t(onErrorRoom)=\"handleOnErrorRoom($event)\"\n   \t(onCameraAccessChange)=\"handleOnCameraAccessChange($event)\"\n\t\n   \t(onParticipantJoined)=\"handleOnParticipantJoined($event)\"\n   \t(onParticipantLeft)=\"handleOnParticipantLeft($event)\"\n\t\n   \t(onStreamAdded)=\"handleOnStreamAdded($event)\"\n   \t(onStreamRemoved)=\"handleOnStreamRemoved($event)\"\n\t\n   \t(onErrorMedia)=\"handleOnErrorMedia()\"\n   \t(onLeaveRoom)=\"handleOnLeaveRoom()\"\n   \t(onNewMessage)=\"handleOnNewMessage($event)\"\n   \t(onCustomNotification)=\"handleOnCustomNotification($event)\">\n\n   \t<div #main class=\"openvidu-appearin\" [ngClass]=\"{'fullscreen': isFullscreen}\">\n\t\t\n   \t\t<!-- WELCOME MESSAGE -->\n   \t\t<div id=\"welcome\" *ngIf=\"welcome\">\n   \t\t\t<header class=\"room-connecting-content-header\">\n   \t\t\t\t<h1>{{_intl.youAreEnteringRoomLabel}}</h1>\n   \t\t\t</header>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.NOT_CONNECTED\">\n   \t\t\t\t<div class=\"ai-spinner\">\n   \t\t\t\t\t<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xml:space=\"preserve\" id=\"Layer_1\" x=\"0px\" y=\"0px\" viewBox=\"0 0 38 38\">\n   \t\t\t\t\t\t<style type=\"text/css\">\n   \t\t\t\t\t\t\t.st0{fill:none;stroke:#D1D1D1;stroke-width:1;}\n   \t\t\t\t\t\t\t.st1{fill:none;stroke:#FF2E63;stroke-width:1;transform-origin:18px 18px;}\n   \t\t\t\t\t\t\t.st2{fill:none;stroke:#41CC8D;stroke-width:1;transform-origin:18px 18px;}\n   \t\t\t\t\t\t</style>\n   \t\t\t\t\t\t<g transform=\"translate(1 1)\">\n   \t\t\t\t\t\t\t<circle class=\"st0\" cx=\"18\" cy=\"18\" r=\"18\"></circle>\n   \t\t\t\t\t\t\t<path class=\"st1\" d=\"M36,18c0-9.9-8.1-18-18-18\"></path>\n   \t\t\t\t\t\t\t<path class=\"st2\" d=\"M18,36c9.9,0,18-8.1,18-18\"></path>\n   \t\t\t\t\t\t</g>\n   \t\t\t\t\t</svg>\n   \t\t\t\t</div>\n   \t\t\t\t<p class=\"text-state\">{{_intl.connectingLabel}}</p>\n   \t\t\t</section>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.CONNECTED_TO_SERVER\">\n   \t\t\t\t<div class=\"ai-spinner\">\n   \t\t\t\t\t<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xml:space=\"preserve\" id=\"Layer_1\" x=\"0px\" y=\"0px\" viewBox=\"0 0 38 38\">\n   \t\t\t\t\t\t<style type=\"text/css\">\n   \t\t\t\t\t\t\t.st0{fill:none;stroke:#D1D1D1;stroke-width:1;}\n   \t\t\t\t\t\t\t.st1{fill:none;stroke:#FF2E63;stroke-width:1;transform-origin:18px 18px;}\n   \t\t\t\t\t\t\t.st2{fill:none;stroke:#41CC8D;stroke-width:1;transform-origin:18px 18px;}\n   \t\t\t\t\t\t</style>\n   \t\t\t\t\t\t<g transform=\"translate(1 1)\">\n   \t\t\t\t\t\t\t<circle class=\"st0\" cx=\"18\" cy=\"18\" r=\"18\"></circle>\n   \t\t\t\t\t\t\t<path class=\"st1\" d=\"M36,18c0-9.9-8.1-18-18-18\"></path>\n   \t\t\t\t\t\t\t<path class=\"st2\" d=\"M18,36c9.9,0,18-8.1,18-18\"></path>\n   \t\t\t\t\t\t</g>\n   \t\t\t\t\t</svg>\n   \t\t\t\t</div>\n   \t\t\t\t<p class=\"text-state\">{{_intl.joiningRoomLabel}}</p>\n   \t\t\t</section>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.CONNECTED_TO_ROOM || connectionUiState == ConnectionState.REQUESTING_CAMERA_ACCESS\">\n   \t\t\t\t<div class=\"ai-spinner\">\n   \t\t\t\t\t<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xml:space=\"preserve\" id=\"Layer_1\" x=\"0px\" y=\"0px\" viewBox=\"0 0 38 38\">\n   \t\t\t\t\t\t<style type=\"text/css\">\n   \t\t\t\t\t\t\t.st0{fill:none;stroke:#D1D1D1;stroke-width:1;}\n   \t\t\t\t\t\t\t.st1{fill:none;stroke:#FF2E63;stroke-width:1;transform-origin:18px 18px;}\n   \t\t\t\t\t\t\t.st2{fill:none;stroke:#41CC8D;stroke-width:1;transform-origin:18px 18px;}\n   \t\t\t\t\t\t</style>\n   \t\t\t\t\t\t<g transform=\"translate(1 1)\">\n   \t\t\t\t\t\t\t<circle class=\"st0\" cx=\"18\" cy=\"18\" r=\"18\"></circle>\n   \t\t\t\t\t\t\t<path class=\"st1\" d=\"M36,18c0-9.9-8.1-18-18-18\"></path>\n   \t\t\t\t\t\t\t<path class=\"st2\" d=\"M18,36c9.9,0,18-8.1,18-18\"></path>\n   \t\t\t\t\t\t</g>\n   \t\t\t\t\t</svg>\n   \t\t\t\t</div>\n   \t\t\t\t<p class=\"text-state\">{{_intl.loadingCameraLabel}}</p>\n   \t\t\t</section>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.CAMERA_ACCESS_DENIED\">\n   \t\t\t\t<h2>{{_intl.browserBlockingLabel}}</h2>\n\n   \t\t\t\t<figure>\n   \t\t\t\t\t<img src=\"https://d1x2efl61akomv.cloudfront.net/images/blocked-camera-chrome.4c7620aa.png\" height=\"38\">\n   \t\t\t\t</figure>\n\n   \t\t\t\t<p class=\"text\">{{_intl.browserBlockingExplainOneLabel}}</p>\n   \t\t\t\t<p class=\"text\">{{_intl.browserBlockingExplainTwoLabel}}</p>\n   \t\t\t</section>\n   \t\t</div>\n\n   \t\t<!-- GOODBYE MESSAGE -->\n   \t\t<div class=\"feedback-wrapper\" *ngIf=\"!session && !welcome\">\n   \t\t\t<div class=\"thank-you-message\">\n   \t\t\t\t<p class=\"body\">You have left the room</p>\n   \t\t\t</div>\n   \t\t</div>\n\n   \t\t<div class=\"wrapper\" *ngIf=\"session && !welcome\">\n   \t\t\t<!-- TOOLBAR -->\n   \t\t\t<div class=\"toolbar\">\n   \t\t\t\t<md-toolbar [color]=\"primary\">\n   \t\t\t\t\t<span>{{sessionId}}</span>\n   \t\t\t\t\t<span class=\"example-spacer\"></span>\n\t\t\t\t\t\n   \t\t\t\t\t<ng-container *ngFor=\"let option of toolbarOptions\">\n   \t\t\t\t\t\t<button md-icon-button *ngIf=\"option.icon !== null\" (click)=\"option.onClick !== null && option.onClick()\" mdTooltip=\"{{(option.label) ? option.label : ''}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t\t<md-icon>{{option.icon}}</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t</ng-container>\n\t\t\t\t\t\n   \t\t\t\t\t<!-- For fullscreen -->\n   \t\t\t\t\t<button md-icon-button (click)=\"toggleFullscreen()\" *ngIf=\"!isFullscreen\" mdTooltip=\"{{_intl.fullscreenLabel}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t<md-icon>fullscreen</md-icon>\n   \t\t\t\t\t</button>\n   \t\t\t\t\t<button md-icon-button (click)=\"toggleFullscreen()\" *ngIf=\"isFullscreen\" mdTooltip=\"{{_intl.exitFullscreenLabel}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t<md-icon>clear</md-icon>\n   \t\t\t\t\t</button>\n   \t\t\t\t</md-toolbar>\n   \t\t\t</div>\n\n   \t\t\t<md-sidenav-container>\n   \t\t\t\t<!-- CHAT BUTTON -->\n   \t\t\t\t<button md-fab class=\"chat-button\" (click)=\"toggleChat()\" *ngIf=\"!showChat\">\n   \t\t\t\t\t<md-icon>chat_bubble</md-icon>\n   \t\t\t\t</button>\n\n   \t\t\t\t<div class=\"md-sidenav-content\">\n   \t\t\t\t\t<!-- MAIN VIDEO -->\n   \t\t\t\t\t<div #panelVideo class=\"panel-videos\">\n   \t\t\t\t\t\t<div class=\"stream-flex\">\n   \t\t\t\t\t\t\t<stream-appearin #streamAppearin *ngFor=\"let s of streams\" class=\"stream\" [stream]=\"s\"\n   \t\t\t\t\t\t\t\t[style.max-width]=\"streamMaxWidth\"\n   \t\t\t\t\t\t\t\t[style.max-height]=\"streamMaxHeight\"\n   \t\t\t\t\t\t\t\t(onSourceAdded)=\"handleOnSourceAdded($event)\">\n   \t\t\t\t\t\t\t</stream-appearin>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t\t<div class=\"chat\" *ngIf=\"showChat\">\n   \t\t\t\t\t\t\t<button class=\"close\" (click)=\"toggleChat()\">\n   \t\t\t\t\t\t\t\t<md-icon>close</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<ul>\n   \t\t\t\t\t\t\t\t<li *ngFor=\"let message of chatMessages\" [ngClass]=\"{'me': message.username == participantId}\">\n   \t\t\t\t\t\t\t\t\t<p>\n   \t\t\t\t\t\t\t\t\t\t{{message.message}}\n   \t\t\t\t\t\t\t\t\t</p>\n   \t\t\t\t\t\t\t\t</li>\n   \t\t\t\t\t\t\t</ul>\n   \t\t\t\t\t\t\t<div class=\"message-input-container\" (submit)=\"sendMessage(messageInput.value);\" accept-charset=\"UTF-8\">\n   \t\t\t\t\t\t\t\t<form>\n   \t\t\t\t\t\t\t\t\t<md-input-container color=\"primary\" floatPlaceholder=\"never\">\n   \t\t\t\t\t\t\t\t\t\t<input mdInput #messageInput placeholder=\"{{_intl.sendAMessageLabel}}\">\n   \t\t\t\t\t\t\t\t\t</md-input-container>\n   \t\t\t\t\t\t\t\t</form>\n   \t\t\t\t\t\t\t</div>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t</div>\n\n   \t\t\t\t\t<!-- BUTTONS & OTHERS VIDEOS -->\n   \t\t\t\t\t<div class=\"bottom-bar\">\n   \t\t\t\t\t\t<div class=\"buttons\">\n   \t\t\t\t\t\t\t<button md-button class=\"toggle-mic\" [ngClass]=\"{'disabled': !openviduApi.micEnabled}\" (click)=\"toggleMic()\">\n   \t\t\t\t\t\t\t\t<md-icon>mic</md-icon>\n   \t\t\t\t\t\t\t\t<md-icon class=\"disabled-icon\">mic_off</md-icon>\n   \t\t\t\t\t\t\t\t<div>{{_intl.muteLabel}}</div>\n   \t\t\t\t\t\t\t\t<div class=\"disabled-text\">{{_intl.unmuteLabel}}</div>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<button md-fab class=\"close-session\" (click)=\"leaveRoom()\" title=\"Leave room\">\n   \t\t\t\t\t\t\t\t<md-icon>close</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<button md-button class=\"toggle-camera\" [ngClass]=\"{'disabled': !openviduApi.camEnabled}\" (click)=\"toggleCamera()\">\n   \t\t\t\t\t\t\t\t<md-icon>videocam</md-icon>\n   \t\t\t\t\t\t\t\t<md-icon class=\"disabled-icon\">videocam_off</md-icon>\n   \t\t\t\t\t\t\t\t<div>{{_intl.videoOffLabel}}</div>\n   \t\t\t\t\t\t\t\t<div class=\"disabled-text\">{{_intl.videoOnLabel}}</div>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t</div>\n   \t\t\t\t</div>\n   \t\t\t</md-sidenav-container>\n   \t\t</div>\n   \t</div>\n\t\n   </openvidu-template>\n\t",
        styles: ["\n   .openvidu-appearin {\n     display: -webkit-box;\n     display: -webkit-flex;\n     display: -ms-flexbox;\n     display: flex;\n     -webkit-box-orient: vertical;\n     -webkit-box-direction: normal;\n     -webkit-flex-direction: column;\n         -ms-flex-direction: column;\n             flex-direction: column; }\n     .openvidu-appearin.fullscreen {\n       width: 100%;\n       height: 100%; }\n     .openvidu-appearin #welcome {\n       -webkit-box-flex: 1;\n       -webkit-flex: 1;\n           -ms-flex: 1;\n               flex: 1;\n       text-align: center;\n       color: #000;\n       margin: 5em auto auto;\n       max-width: 412px;\n       padding: 1em; }\n       .openvidu-appearin #welcome header {\n         margin-bottom: 18px; }\n         .openvidu-appearin #welcome header h1 {\n           margin: 0;\n           font-weight: 400;\n           line-height: 28px;\n           font-size: 20px; }\n       .openvidu-appearin #welcome section {\n         padding: 0 0 2em 0; }\n         .openvidu-appearin #welcome section .ai-spinner {\n           height: 120px;\n           width: 120px;\n           margin: 0 auto;\n           padding: 15px;\n           -webkit-transform-origin: 50% 50%;\n               -ms-transform-origin: 50% 50%;\n                   transform-origin: 50% 50%;\n           -webkit-animation: spin .7s linear infinite;\n                   animation: spin .7s linear infinite;\n           -webkit-box-sizing: border-box;\n                   box-sizing: border-box; }\n         .openvidu-appearin #welcome section .text-state {\n           font-size: 24px; }\n         .openvidu-appearin #welcome section .text-body-main {\n           font-size: 18px; }\n         .openvidu-appearin #welcome section .ui-button {\n           background: #ff2e63; }\n         .openvidu-appearin #welcome section .ui-button, .openvidu-appearin #welcome section .ui-button-invis, .openvidu-appearin #welcome section .ui-button-outline {\n           display: inline-block;\n           border-radius: 3px;\n           border: solid 0;\n           -webkit-box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.15);\n                   box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.15);\n           cursor: pointer;\n           font-size: 14px;\n           padding: 10px 12px 10px 12px;\n           line-height: 20px;\n           text-decoration: none;\n           position: relative;\n           text-align: center;\n           margin-top: 4px;\n           margin-bottom: 4px;\n           outline: 0;\n           font-weight: 400;\n           word-wrap: break-word;\n           border: solid #ff2e63 0;\n           color: #fff;\n           -webkit-font-smoothing: subpixel-antialiased;\n           -moz-osx-font-smoothing: auto; }\n         .openvidu-appearin #welcome section .video-preview-wrapper {\n           height: 256px;\n           background: rgba(0, 0, 0, 0.1);\n           overflow: hidden;\n           display: -webkit-box;\n           display: -webkit-flex;\n           display: -ms-flexbox;\n           display: flex;\n           -webkit-box-align: center;\n           -webkit-align-items: center;\n               -ms-flex-align: center;\n                   align-items: center;\n           -webkit-box-pack: center;\n           -webkit-justify-content: center;\n               -ms-flex-pack: center;\n                   justify-content: center;\n           -webkit-box-orient: vertical;\n           -webkit-box-direction: normal;\n           -webkit-flex-direction: column;\n               -ms-flex-direction: column;\n                   flex-direction: column; }\n         .openvidu-appearin #welcome section .camera-off-icon md-icon {\n           height: 84px;\n           width: 500px; }\n           .openvidu-appearin #welcome section .camera-off-icon md-icon .fill {\n             fill: #333; }\n     .openvidu-appearin .feedback-wrapper {\n       -webkit-box-flex: 1;\n       -webkit-flex: 1;\n           -ms-flex: 1;\n               flex: 1;\n       text-align: center;\n       background-color: rgba(0, 0, 0, 0.5);\n       padding: 50px;\n       border-radius: 3px; }\n       .openvidu-appearin .feedback-wrapper .thank-you-message {\n         font-size: 34px;\n         margin-top: .5em;\n         margin-bottom: 1.5em;\n         color: #fff; }\n       .openvidu-appearin .feedback-wrapper p button {\n         background: #41cc8d; }\n     .openvidu-appearin .wrapper {\n       -webkit-box-flex: 1;\n       -webkit-flex: 1;\n           -ms-flex: 1;\n               flex: 1;\n       display: -webkit-box;\n       display: -webkit-flex;\n       display: -ms-flexbox;\n       display: flex;\n       -webkit-box-orient: vertical;\n       -webkit-box-direction: normal;\n       -webkit-flex-direction: column;\n           -ms-flex-direction: column;\n               flex-direction: column;\n       background: -webkit-gradient(linear, left top, left bottom, from(#360033), to(#0b8793));\n       background: -webkit-linear-gradient(#360033, #0b8793);\n       background: linear-gradient(#360033, #0b8793); }\n       .openvidu-appearin .wrapper .toolbar .mat-toolbar {\n         background: transparent;\n         color: #fff; }\n       .openvidu-appearin .wrapper .toolbar .example-icon {\n         padding: 0 14px; }\n       .openvidu-appearin .wrapper .toolbar .example-spacer {\n         -webkit-box-flex: 1;\n         -webkit-flex: 1 1 auto;\n             -ms-flex: 1 1 auto;\n                 flex: 1 1 auto; }\n       .openvidu-appearin .wrapper md-sidenav-container {\n         -webkit-box-flex: 1;\n         -webkit-flex: 1;\n             -ms-flex: 1;\n                 flex: 1;\n         background: transparent; }\n         .openvidu-appearin .wrapper md-sidenav-container .chat-button {\n           position: absolute;\n           right: 12px;\n           bottom: 2.1em;\n           border: 2px solid #fff;\n           -webkit-transition: opacity .2s;\n           transition: opacity .2s;\n           border-radius: 50%;\n           background-color: rgba(0, 0, 0, 0.4);\n           cursor: pointer;\n           outline: 0;\n           margin: 0;\n           color: #fff;\n           z-index: 99; }\n         .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content {\n           display: -webkit-box;\n           display: -webkit-flex;\n           display: -ms-flexbox;\n           display: flex;\n           -webkit-box-orient: vertical;\n           -webkit-box-direction: normal;\n           -webkit-flex-direction: column;\n               -ms-flex-direction: column;\n                   flex-direction: column;\n           height: 100%; }\n           .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos {\n             -webkit-box-flex: 1;\n             -webkit-flex: 1;\n                 -ms-flex: 1;\n                     flex: 1;\n             display: -webkit-box;\n             display: -webkit-flex;\n             display: -ms-flexbox;\n             display: flex;\n             min-height: 200px; }\n             .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .stream-flex {\n               -webkit-box-flex: 1;\n               -webkit-flex: 1;\n                   -ms-flex: 1;\n                       flex: 1;\n               display: -webkit-box;\n               display: -webkit-flex;\n               display: -ms-flexbox;\n               display: flex;\n               -webkit-box-orient: horizontal;\n               -webkit-box-direction: normal;\n               -webkit-flex-direction: row;\n                   -ms-flex-direction: row;\n                       flex-direction: row;\n               -webkit-align-content: center;\n                   -ms-flex-line-pack: center;\n                       align-content: center;\n               -webkit-flex-wrap: wrap;\n                   -ms-flex-wrap: wrap;\n                       flex-wrap: wrap;\n               -webkit-box-pack: center;\n               -webkit-justify-content: center;\n                   -ms-flex-pack: center;\n                       justify-content: center; }\n             .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat {\n               display: -webkit-box;\n               display: -webkit-flex;\n               display: -ms-flexbox;\n               display: flex;\n               -webkit-box-orient: vertical;\n               -webkit-box-direction: normal;\n               -webkit-flex-direction: column;\n                   -ms-flex-direction: column;\n                       flex-direction: column;\n               -webkit-box-pack: end;\n               -webkit-justify-content: flex-end;\n                   -ms-flex-pack: end;\n                       justify-content: flex-end;\n               position: relative;\n               background-color: rgba(0, 0, 0, 0.5);\n               border-radius: 3px 3px 0 0;\n               margin: 0px 10px;\n               width: 30%;\n               max-width: 400px; }\n               .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat .close {\n                 background: rgba(0, 0, 0, 0.4);\n                 color: #fff;\n                 outline: none;\n                 border: none;\n                 padding: 4px;\n                 border-radius: 50%;\n                 width: 36px;\n                 position: absolute;\n                 top: 0px;\n                 right: 0px;\n                 cursor: pointer; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat .close:hover {\n                   background-color: #000; }\n               .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat ul {\n                 -webkit-box-flex: 1;\n                 -webkit-flex: 1;\n                     -ms-flex: 1;\n                         flex: 1;\n                 padding: 0px 10px 10px 10px;\n                 overflow: auto; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat ul li {\n                   display: -webkit-box;\n                   display: -webkit-flex;\n                   display: -ms-flexbox;\n                   display: flex;\n                   -webkit-box-orient: horizontal;\n                   -webkit-box-direction: normal;\n                   -webkit-flex-direction: row;\n                       -ms-flex-direction: row;\n                           flex-direction: row;\n                   -webkit-box-pack: start;\n                   -webkit-justify-content: flex-start;\n                       -ms-flex-pack: start;\n                           justify-content: flex-start;\n                   padding: 6px 14px; }\n                   .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat ul li.me {\n                     -webkit-box-orient: horizontal;\n                     -webkit-box-direction: reverse;\n                     -webkit-flex-direction: row-reverse;\n                         -ms-flex-direction: row-reverse;\n                             flex-direction: row-reverse; }\n                     .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat ul li.me p {\n                       background-color: #ffcad7; }\n                   .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat ul li p {\n                     background-color: #f5fcf9;\n                     margin: 0;\n                     margin-right: 20px;\n                     padding: 7px 8px 6px;\n                     font-size: 12px;\n                     line-height: 1.3333;\n                     background-color: #f5fcf9;\n                     border-radius: 3px;\n                     word-wrap: break-word;\n                     max-width: -webkit-calc(100% - 68px);\n                     max-width: calc(100% - 68px);\n                     color: rgba(0, 0, 0, 0.87); }\n               .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat .message-input-container {\n                 background: #fff;\n                 padding: 0px 10px; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .panel-videos .chat .message-input-container md-input-container {\n                   width: 100%; }\n           .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar {\n             display: -webkit-box;\n             display: -webkit-flex;\n             display: -ms-flexbox;\n             display: flex;\n             margin: 4px 0px 4px 0px; }\n             .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons {\n               background-color: rgba(0, 0, 0, 0.5);\n               border-radius: 3px;\n               display: -webkit-box;\n               display: -webkit-flex;\n               display: -ms-flexbox;\n               display: flex;\n               -webkit-box-pack: justify;\n               -webkit-justify-content: space-between;\n                   -ms-flex-pack: justify;\n                       justify-content: space-between;\n               margin: 0 auto;\n               overflow: hidden;\n               -webkit-box-align: center;\n               -webkit-align-items: center;\n                   -ms-flex-align: center;\n                       align-items: center; }\n               .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button {\n                 background-color: transparent;\n                 -webkit-box-align: center;\n                 -webkit-align-items: center;\n                     -ms-flex-align: center;\n                         align-items: center;\n                 -webkit-box-sizing: border-box;\n                         box-sizing: border-box;\n                 color: #fff;\n                 display: -webkit-box;\n                 display: -webkit-flex;\n                 display: -ms-flexbox;\n                 display: flex;\n                 -webkit-box-orient: vertical;\n                 -webkit-box-direction: normal;\n                 -webkit-flex-flow: column nowrap;\n                     -ms-flex-flow: column nowrap;\n                         flex-flow: column nowrap;\n                 font-size: 12px;\n                 height: 54px;\n                 -webkit-box-pack: center;\n                 -webkit-justify-content: center;\n                     -ms-flex-pack: center;\n                         justify-content: center;\n                 padding: 0 8px;\n                 text-align: center;\n                 width: 92px; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button.close-session {\n                   background-color: #ff2e63;\n                   height: 46px;\n                   width: 46px;\n                   margin: 0 16px; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button.disabled {\n                   background-color: #ff2e63; }\n                   .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button.disabled md-icon {\n                     display: none; }\n                     .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button.disabled md-icon.disabled-icon {\n                       display: inline-block; }\n                   .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button.disabled div {\n                     display: none; }\n                     .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button.disabled div.disabled-text {\n                       display: block; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button md-icon {\n                   display: inline-block; }\n                   .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button md-icon.disabled-icon {\n                     display: none; }\n                 .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button div {\n                   margin-bottom: 4px;\n                   text-shadow: 0 1px 1px rgba(0, 0, 0, 0.4);\n                   white-space: nowrap;\n                   width: 100%;\n                   line-height: 10px; }\n                   .openvidu-appearin .wrapper md-sidenav-container .md-sidenav-content .bottom-bar .buttons button div.disabled-text {\n                     display: none; }\n\n   @-webkit-keyframes spin {\n     from {\n       -webkit-transform: rotate(0);\n               transform: rotate(0); }\n     to {\n       -webkit-transform: rotate(360deg);\n               transform: rotate(360deg); } }\n\n   @keyframes spin {\n     from {\n       -webkit-transform: rotate(0);\n               transform: rotate(0); }\n     to {\n       -webkit-transform: rotate(360deg);\n               transform: rotate(360deg); } }\n\t"]
    }),
    __metadata("design:paramtypes", [core_1.Renderer2, angular_bigscreen_1.BigScreenService,
        openvidu_appearin_intl_1.OpenViduAppearinIntl])
], OpenViduAppearinComponent);
exports.OpenViduAppearinComponent = OpenViduAppearinComponent;
