import { ElementRef, EventEmitter, OnInit, OnDestroy, QueryList, Renderer2 } from '@angular/core';
import { MdSidenav } from '@angular/material';
import { BigScreenService } from 'angular-bigscreen';
import { Stream } from 'openvidu-browser';
import { OpenViduDirective, CameraAccessEvent, ErrorEvent, MessageEvent, ParticipantEvent, RoomConnectedEvent, StreamEvent } from '../openvidu.directive';
import { StreamGoToMeetingComponent } from './stream-gotomeeting/stream-gotomeeting.component';
import { OpenViduGoToMeetingIntl } from './openvidu-gotomeeting-intl';
export declare enum ConnectionState {
    NOT_CONNECTED = 0,
    CONNECTED_TO_SERVER = 1,
    CONNECTED_TO_ROOM = 2,
    REQUESTING_CAMERA_ACCESS = 3,
    CAMERA_ACCESS_GRANTED = 4,
    CAMERA_ACCESS_DENIED = 5,
}
export interface ToolbarOption {
    label?: string;
    icon: string;
    onClick?: Function;
}
export declare class OpenViduGoToMeetingComponent implements OnInit, OnDestroy {
    private renderer;
    private bigScreenService;
    _intl: OpenViduGoToMeetingIntl;
    wsUrl: string;
    sessionId: string;
    participantId: string;
    apiKey: string;
    token: string;
    showSecondaryContent: boolean;
    toolbarOptions: ToolbarOption[];
    onRoomConnected: EventEmitter<void>;
    onErrorRoom: EventEmitter<any>;
    onRoomClosed: EventEmitter<void>;
    onLostConnection: EventEmitter<any>;
    onParticipantJoined: EventEmitter<any>;
    onParticipantLeft: EventEmitter<any>;
    onNewMessage: EventEmitter<any>;
    onErrorMedia: EventEmitter<any>;
    onLeaveRoom: EventEmitter<void>;
    onCustomNotification: EventEmitter<any>;
    openviduApi: OpenViduDirective;
    mainElement: ElementRef;
    sidenav: MdSidenav;
    messageInput: ElementRef;
    panelVideo: ElementRef;
    streamGoToMeeting: QueryList<StreamGoToMeetingComponent>;
    streamMaxWidth: string;
    streamMaxHeight: string;
    userMessage: string;
    isFullscreen: boolean;
    welcome: boolean;
    showChat: boolean;
    showPeople: boolean;
    mainStream: Stream;
    streams: Stream[];
    chatMessages: any[];
    ConnectionState: typeof ConnectionState;
    connectionUiState: ConnectionState;
    private session;
    private participants;
    private myCamera;
    constructor(renderer: Renderer2, bigScreenService: BigScreenService, _intl: OpenViduGoToMeetingIntl);
    ngOnInit(): void;
    ngOnDestroy(): void;
    onResize(): void;
    toggleMic(): void;
    toggleCamera(): void;
    togglePeople(): void;
    toggleChat(): void;
    toggleFullscreen(): void;
    onSidenavCloseStart(): void;
    onChangeSplitPane(): void;
    sendMessage(text: string): void;
    sendCustomNotification(obj: any, callback: any): void;
    leaveRoom(): void;
    handleOnUpdateMainSpeaker(streamEvent: StreamEvent): void;
    handleOnServerConnected(): void;
    handleOnErrorServer(errorEvent: ErrorEvent): void;
    handleOnRoomConnected(roomConnectedEvent: RoomConnectedEvent): void;
    handleOnErrorRoom(): void;
    handleOnCameraAccessChange(cameraEvent: CameraAccessEvent): void;
    handleOnRoomClosed(): void;
    handleOnLostConnection(): void;
    handleOnParticipantJoined(participantEvent: ParticipantEvent): void;
    handleOnParticipantLeft(participantEvent: ParticipantEvent): void;
    handleOnErrorMedia(errorEvent: ErrorEvent): void;
    handleOnStreamAdded(streamEvent: StreamEvent): void;
    handleOnStreamRemoved(streamEvent: StreamEvent): void;
    handleOnCustomNotification(object: any): void;
    handleOnLeaveRoom(): void;
    handleOnNewMessage(messageEvent: MessageEvent): void;
    handleOnSourceAdded(): void;
    private setUserMessage(msg);
    private resizeStreamsManually();
    private auxResizeStreamsManually();
}
