"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
// Angular Material
var material_1 = require("@angular/material");
// Fullscreen Service
var angular_bigscreen_1 = require("angular-bigscreen");
var openvidu_directive_1 = require("../openvidu.directive");
// i18n Labels and Messages
var openvidu_gotomeeting_intl_1 = require("./openvidu-gotomeeting-intl");
var ConnectionState;
(function (ConnectionState) {
    ConnectionState[ConnectionState["NOT_CONNECTED"] = 0] = "NOT_CONNECTED";
    ConnectionState[ConnectionState["CONNECTED_TO_SERVER"] = 1] = "CONNECTED_TO_SERVER";
    ConnectionState[ConnectionState["CONNECTED_TO_ROOM"] = 2] = "CONNECTED_TO_ROOM";
    ConnectionState[ConnectionState["REQUESTING_CAMERA_ACCESS"] = 3] = "REQUESTING_CAMERA_ACCESS";
    ConnectionState[ConnectionState["CAMERA_ACCESS_GRANTED"] = 4] = "CAMERA_ACCESS_GRANTED";
    ConnectionState[ConnectionState["CAMERA_ACCESS_DENIED"] = 5] = "CAMERA_ACCESS_DENIED";
})(ConnectionState = exports.ConnectionState || (exports.ConnectionState = {}));
;
var OpenViduGoToMeetingComponent = (function () {
    function OpenViduGoToMeetingComponent(renderer, bigScreenService, _intl) {
        this.renderer = renderer;
        this.bigScreenService = bigScreenService;
        this._intl = _intl;
        // Unique Inputs
        // To show secondary content
        this.showSecondaryContent = false;
        // To set new options in menu
        this.toolbarOptions = [];
        // Outputs
        this.onRoomConnected = new core_1.EventEmitter();
        this.onErrorRoom = new core_1.EventEmitter();
        this.onRoomClosed = new core_1.EventEmitter();
        this.onLostConnection = new core_1.EventEmitter();
        this.onParticipantJoined = new core_1.EventEmitter();
        this.onParticipantLeft = new core_1.EventEmitter();
        this.onNewMessage = new core_1.EventEmitter();
        this.onErrorMedia = new core_1.EventEmitter();
        this.onLeaveRoom = new core_1.EventEmitter();
        this.onCustomNotification = new core_1.EventEmitter();
        // Responsive streams
        this.streamMaxWidth = '100%';
        this.streamMaxHeight = '100%';
        // Flags for HTML elements
        this.userMessage = '';
        this.isFullscreen = false;
        this.welcome = true;
        this.showChat = false;
        this.showPeople = false;
        // Rest of peers
        this.streams = [];
        // Chat
        this.chatMessages = [];
        // Connection stats
        this.ConnectionState = ConnectionState;
        this.connectionUiState = ConnectionState.NOT_CONNECTED;
        // Participants
        this.participants = {};
        this.welcome = true;
        this.setUserMessage(this._intl.loadingLabel);
    }
    OpenViduGoToMeetingComponent.prototype.ngOnInit = function () {
        var _this = this;
        // Display message
        this.setUserMessage(this._intl.connectingLabel);
        // Set fullscreen listener
        this.bigScreenService.onChange(function () {
            // No need to check if mainElement is the one with fullscreen
            _this.isFullscreen = _this.bigScreenService.isFullscreen();
            // Fix: Resize videos
            setTimeout(function () {
                _this.resizeStreamsManually();
            }, 1000);
        });
    };
    OpenViduGoToMeetingComponent.prototype.ngOnDestroy = function () {
        this.bigScreenService.exit();
        this.leaveRoom();
    };
    /*---------------------*/
    /* GUI RELATED METHODS */
    /*---------------------*/
    OpenViduGoToMeetingComponent.prototype.onResize = function () {
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.toggleMic = function () {
        this.openviduApi.micEnabled = !this.openviduApi.micEnabled;
    };
    OpenViduGoToMeetingComponent.prototype.toggleCamera = function () {
        this.openviduApi.camEnabled = !this.openviduApi.camEnabled;
    };
    OpenViduGoToMeetingComponent.prototype.togglePeople = function () {
        if (!this.showPeople) {
            this.showChat = false;
            this.showPeople = true;
            this.sidenav.open();
        }
        else {
            this.sidenav.close();
        }
    };
    OpenViduGoToMeetingComponent.prototype.toggleChat = function () {
        if (!this.showChat) {
            this.showPeople = false;
            this.showChat = true;
            this.sidenav.open();
        }
        else {
            this.sidenav.close();
        }
    };
    OpenViduGoToMeetingComponent.prototype.toggleFullscreen = function () {
        if (this.bigScreenService.isFullscreen()) {
            this.bigScreenService.exit();
        }
        else {
            this.bigScreenService.request(this.mainElement.nativeElement);
        }
    };
    OpenViduGoToMeetingComponent.prototype.onSidenavCloseStart = function () {
        this.showPeople = false;
        this.showChat = false;
    };
    OpenViduGoToMeetingComponent.prototype.onChangeSplitPane = function () {
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.sendMessage = function (text) {
        // Clean input
        this.messageInput.nativeElement.value = null;
        //this.renderer.setValue(this.messageInput, null);
        // Send to OpenVidu server
        this.openviduApi.sendMessage(text);
    };
    OpenViduGoToMeetingComponent.prototype.sendCustomNotification = function (obj, callback) {
        this.openviduApi.sendCustomNotification(obj, callback);
    };
    OpenViduGoToMeetingComponent.prototype.leaveRoom = function () {
        // Reset
        this.mainStream = null;
        this.streams = [];
        this.chatMessages = [];
        this.session = null;
        this.participants = {};
        // Display message
        this.setUserMessage(this._intl.youLeftTheRoomLabel);
        this.openviduApi.leaveRoom();
    };
    /*------------------------*/
    /* HANDLE OPENVIDU EVENTS */
    /*------------------------*/
    OpenViduGoToMeetingComponent.prototype.handleOnUpdateMainSpeaker = function (streamEvent) {
        // Check if stream exists
        if (this.streams.indexOf(streamEvent.stream) < 0) {
            this.streams.push(streamEvent.stream);
        }
        // Set main stream
        this.mainStream = streamEvent.stream;
        // Check if participant exists
        if (!this.participants[this.mainStream.getParticipant().getId()]) {
            this.participants[this.mainStream.getParticipant().getId()] = this.mainStream.getParticipant();
        }
    };
    OpenViduGoToMeetingComponent.prototype.handleOnServerConnected = function () {
        this.setUserMessage(this._intl.connectingToRoomLabel);
        this.connectionUiState = ConnectionState.CONNECTED_TO_SERVER;
    };
    OpenViduGoToMeetingComponent.prototype.handleOnErrorServer = function (errorEvent) {
        if (errorEvent.error) {
            this.setUserMessage(errorEvent.error.message);
        }
    };
    OpenViduGoToMeetingComponent.prototype.handleOnRoomConnected = function (roomConnectedEvent) {
        if (roomConnectedEvent && roomConnectedEvent.session) {
            this.session = roomConnectedEvent.session;
        }
        // Emit event
        this.onRoomConnected.emit();
        this.connectionUiState = ConnectionState.CONNECTED_TO_ROOM;
    };
    OpenViduGoToMeetingComponent.prototype.handleOnErrorRoom = function () {
        this.setUserMessage(this._intl.errorRoom);
        // Emit event
        this.onErrorRoom.emit();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnCameraAccessChange = function (cameraEvent) {
        if (cameraEvent.access) {
            // All good :)
            this.myCamera = cameraEvent.camera;
            if (this.streams.indexOf(this.myCamera) < 0) {
                this.streams.push(this.myCamera);
            }
            this.welcome = false;
            this.connectionUiState = ConnectionState.CAMERA_ACCESS_GRANTED;
        }
        else if (!cameraEvent.access) {
            // No camera :(
            this.connectionUiState = ConnectionState.CAMERA_ACCESS_DENIED;
        }
    };
    OpenViduGoToMeetingComponent.prototype.handleOnRoomClosed = function () {
        this.session = null;
        // Emit event
        this.onRoomClosed.emit();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnLostConnection = function () {
        if (!this.session) {
            // Emit event
            this.onLostConnection.emit({
                error: new Error('Lost connection with the server')
            });
        }
        else {
            // Emit event
            this.onLostConnection.emit();
        }
    };
    OpenViduGoToMeetingComponent.prototype.handleOnParticipantJoined = function (participantEvent) {
        var newParticipant = participantEvent.participant;
        this.participants[newParticipant.getId()] = newParticipant;
        // Emit event
        this.onParticipantJoined.emit({
            participantId: newParticipant.getId()
        });
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnParticipantLeft = function (participantEvent) {
        var oldParticipant = participantEvent.participant;
        delete this.participants[oldParticipant.getId()];
        // Emit event
        this.onParticipantLeft.emit({
            participantId: oldParticipant.getId()
        });
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnErrorMedia = function (errorEvent) {
        // Emit event
        this.onErrorMedia.emit({
            error: errorEvent.error
        });
    };
    OpenViduGoToMeetingComponent.prototype.handleOnStreamAdded = function (streamEvent) {
        var newStream = streamEvent.stream;
        if (this.streams.indexOf(newStream) < 0) {
            this.streams.push(newStream);
        }
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnStreamRemoved = function (streamEvent) {
        var oldStream = streamEvent.stream;
        this.streams.splice(this.streams.indexOf(oldStream), 1);
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnCustomNotification = function (object) {
        // Emit event
        this.onCustomNotification.emit(object);
    };
    OpenViduGoToMeetingComponent.prototype.handleOnLeaveRoom = function () {
        // Emit event
        this.onLeaveRoom.emit();
    };
    OpenViduGoToMeetingComponent.prototype.handleOnNewMessage = function (messageEvent) {
        // Fix: to get usernam
        var dataObj = JSON.parse(messageEvent.participant.data);
        // Handle message
        this.chatMessages.push({
            username: dataObj.username,
            message: messageEvent.message,
            date: new Date() // Use current date
        });
        this.onNewMessage.emit(messageEvent);
    };
    OpenViduGoToMeetingComponent.prototype.handleOnSourceAdded = function () {
        // Fix: manually resize panel
        this.resizeStreamsManually();
    };
    OpenViduGoToMeetingComponent.prototype.setUserMessage = function (msg) {
        this.userMessage = msg;
    };
    OpenViduGoToMeetingComponent.prototype.resizeStreamsManually = function () {
        var obj = this.auxResizeStreamsManually();
        //console.log(obj);
        if (!obj.error) {
            this.streamMaxWidth = obj.width + 'px';
            this.streamMaxHeight = obj.height + 'px';
        }
    };
    OpenViduGoToMeetingComponent.prototype.auxResizeStreamsManually = function () {
        if (!this.panelVideo)
            return { error: true };
        var clientRect = this.panelVideo.nativeElement.getBoundingClientRect();
        var maxDimensions = {
            maxW: 0,
            maxH: 0
        };
        this.streamGoToMeeting.forEach(function (streamGoToMeetingEl) {
            var videoEl = streamGoToMeetingEl.videoStream.nativeElement;
            if (videoEl.videoWidth > maxDimensions.maxW) {
                if (videoEl.videoHeight > maxDimensions.maxH) {
                    maxDimensions.maxW = videoEl.videoWidth;
                    maxDimensions.maxH = videoEl.videoHeight;
                }
            }
        });
        //console.log(maxDimensions);
        var numElements = this.streamGoToMeeting.length;
        var width = clientRect.width;
        var height = clientRect.height;
        var area = height * width;
        var elementArea = parseInt((area / numElements) + '');
        // Calculate proportions
        var maxProportions = {
            maxW: 0,
            maxH: 0,
        };
        if (width > height) {
            // It'a horizontal rectangle
            maxProportions.maxW = maxDimensions.maxW / maxDimensions.maxH;
            maxProportions.maxH = ((maxDimensions.maxW / maxDimensions.maxH) * maxDimensions.maxH) / maxDimensions.maxW;
        }
        else if (height > width) {
            // It'a vertcal rectangle
            maxProportions.maxW = ((maxDimensions.maxH / maxDimensions.maxW) * maxDimensions.maxW) / maxDimensions.maxH;
            maxProportions.maxH = maxDimensions.maxH / maxDimensions.maxW;
        }
        else {
            // It's a square
            maxProportions.maxW = maxDimensions.maxW / maxDimensions.maxH;
            maxProportions.maxH = ((maxDimensions.maxW / maxDimensions.maxH) * maxDimensions.maxH) / maxDimensions.maxW;
        }
        //console.log(maxProportions);
        var elementWidth = parseInt(Math.sqrt(elementArea * (maxProportions.maxW / maxProportions.maxH)) + '');
        var elementHeight = parseInt(Math.sqrt(elementArea * (maxProportions.maxH / maxProportions.maxW)) + '');
        //console.log(elementWidth);
        // We now need to fit the squares. Let's reduce the square size
        // so an integer number fits the width.
        var numX = Math.ceil(width / elementWidth);
        elementWidth = width / numX;
        elementHeight = elementWidth * (maxProportions.maxH / maxProportions.maxW);
        while (numX <= numElements) {
            // With a bit of luck, we are done.
            if (Math.floor(height / elementHeight) * numX >= numElements) {
                // They all fit! We are done!
                return { width: elementWidth, height: elementHeight };
            }
            // They don't fit. Make room for one more square i each row.
            numX++;
            elementWidth = width / numX;
            elementHeight = elementWidth * (maxProportions.maxH / maxProportions.maxW);
        }
        // Still doesn't fit? The window must be very wide
        // and low.
        elementHeight = height;
        return { width: elementWidth, height: elementHeight };
    };
    return OpenViduGoToMeetingComponent;
}());
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduGoToMeetingComponent.prototype, "wsUrl", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduGoToMeetingComponent.prototype, "sessionId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduGoToMeetingComponent.prototype, "participantId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduGoToMeetingComponent.prototype, "apiKey", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduGoToMeetingComponent.prototype, "token", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", Boolean)
], OpenViduGoToMeetingComponent.prototype, "showSecondaryContent", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", Array)
], OpenViduGoToMeetingComponent.prototype, "toolbarOptions", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onRoomConnected", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onErrorRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onRoomClosed", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onLostConnection", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onParticipantJoined", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onParticipantLeft", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onNewMessage", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onErrorMedia", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onLeaveRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduGoToMeetingComponent.prototype, "onCustomNotification", void 0);
__decorate([
    core_1.ViewChild('openviduApi'),
    __metadata("design:type", openvidu_directive_1.OpenViduDirective)
], OpenViduGoToMeetingComponent.prototype, "openviduApi", void 0);
__decorate([
    core_1.ViewChild('main'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduGoToMeetingComponent.prototype, "mainElement", void 0);
__decorate([
    core_1.ViewChild('sidenav'),
    __metadata("design:type", material_1.MdSidenav)
], OpenViduGoToMeetingComponent.prototype, "sidenav", void 0);
__decorate([
    core_1.ViewChild('messageInput'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduGoToMeetingComponent.prototype, "messageInput", void 0);
__decorate([
    core_1.ViewChild('panelVideo'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduGoToMeetingComponent.prototype, "panelVideo", void 0);
__decorate([
    core_1.ViewChildren('streamGoToMeeting'),
    __metadata("design:type", core_1.QueryList)
], OpenViduGoToMeetingComponent.prototype, "streamGoToMeeting", void 0);
__decorate([
    core_1.HostListener('window:resize', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], OpenViduGoToMeetingComponent.prototype, "onResize", null);
OpenViduGoToMeetingComponent = __decorate([
    core_1.Component({
        selector: 'openvidu-gotomeeting',
        template: "\n   <openvidu-template\n   \t#openviduApi=\"openviduApi\"\n   \t[wsUrl]=\"wsUrl\"\n   \t[sessionId]=\"sessionId\"\n   \t[participantId]=\"participantId\"\n\t\n   \t(onUpdateMainSpeaker)=\"handleOnUpdateMainSpeaker($event)\"\n\t\n   \t(onServerConnected)=\"handleOnServerConnected($event)\"\n   \t(onErrorServer)=\"handleOnErrorServer($event)\"\n   \t(onRoomConnected)=\"handleOnRoomConnected($event)\"\n   \t(onErrorRoom)=\"handleOnErrorRoom($event)\"\n   \t(onCameraAccessChange)=\"handleOnCameraAccessChange($event)\"\n\t\n   \t(onParticipantJoined)=\"handleOnParticipantJoined($event)\"\n   \t(onParticipantLeft)=\"handleOnParticipantLeft($event)\"\n\t\n   \t(onStreamAdded)=\"handleOnStreamAdded($event)\"\n   \t(onStreamRemoved)=\"handleOnStreamRemoved($event)\"\n\t\n   \t(onErrorMedia)=\"handleOnErrorMedia()\"\n   \t(onLeaveRoom)=\"handleOnLeaveRoom()\"\n   \t(onNewMessage)=\"handleOnNewMessage($event)\"\n   \t(onCustomNotification)=\"handleOnCustomNotification($event)\">\n\n   \t<div #main class=\"openvidu-gotomeeting\" [ngClass]=\"{'fullscreen': isFullscreen}\">\n\t\n   \t\t<!-- WELCOME MESSAGE -->\n   \t\t<div id=\"welcome\" *ngIf=\"welcome\">\n   \t\t\t<header class=\"room-connecting-content-header\">\n   \t\t\t\t<h1>{{_intl.youAreEnteringRoomLabel}}</h1>\n   \t\t\t</header>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.NOT_CONNECTED\">\n   \t\t\t\t<div class=\"spinner\">\n   \t\t\t\t\t<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xml:space=\"preserve\" x=\"0px\" y=\"0px\" viewBox=\"0 0 512 512\" width=\"100\" height=\"100\">\n   \t\t\t\t\t\t<g transform=\"translate(1, 42)\">\n   \t\t\t\t\t\t\t<path class=\"ring\" d=\"M277.334 1.088v-42.666c124.33 10.283 223.317 109.269 233.6 233.6h-42.666c-10.048-100.65-90.304-180.906-190.934-190.933zM234.667 425.579v42.666c-124.331-10.262-223.317-109.248-233.6-233.578h42.666c10.048 100.629 90.304 180.886 190.934 190.912zM43.755 192h-42.666c10.261-124.33 109.248-223.317 233.578-233.6v42.666c-100.63 10.048-180.886 90.304-190.912 190.934zM468.245 234.667h42.666c-10.262 124.331-109.248 223.317-233.579 233.6v-42.666c100.63-10.048 180.885-90.304 190.912-190.934z\" ></path>\n   \t\t\t\t\t\t\t<path class=\"segment\" d=\"M234.667 425.579v42.666c-124.331-10.262-223.317-109.248-233.6-233.578h42.666c10.048 100.629 90.304 180.886 190.934 190.912z\"></path>\n   \t\t\t\t\t\t</g>\n   \t\t\t\t\t</svg>\n   \t\t\t\t</div>\n   \t\t\t\t<p class=\"text-state\">{{_intl.connectingLabel}}</p>\n   \t\t\t</section>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.CONNECTED_TO_SERVER\">\t\t\t\t\n   \t\t\t\t<div class=\"spinner\">\n   \t\t\t\t\t<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xml:space=\"preserve\" x=\"0px\" y=\"0px\" viewBox=\"0 0 512 512\" width=\"100\" height=\"100\">\n   \t\t\t\t\t\t<g transform=\"translate(1, 42)\">\n   \t\t\t\t\t\t\t<path class=\"ring\" d=\"M277.334 1.088v-42.666c124.33 10.283 223.317 109.269 233.6 233.6h-42.666c-10.048-100.65-90.304-180.906-190.934-190.933zM234.667 425.579v42.666c-124.331-10.262-223.317-109.248-233.6-233.578h42.666c10.048 100.629 90.304 180.886 190.934 190.912zM43.755 192h-42.666c10.261-124.33 109.248-223.317 233.578-233.6v42.666c-100.63 10.048-180.886 90.304-190.912 190.934zM468.245 234.667h42.666c-10.262 124.331-109.248 223.317-233.579 233.6v-42.666c100.63-10.048 180.885-90.304 190.912-190.934z\" ></path>\n   \t\t\t\t\t\t\t<path class=\"segment\" d=\"M234.667 425.579v42.666c-124.331-10.262-223.317-109.248-233.6-233.578h42.666c10.048 100.629 90.304 180.886 190.934 190.912z\"></path>\n   \t\t\t\t\t\t</g>\n   \t\t\t\t\t</svg>\n   \t\t\t\t</div>\n\t\t\t\t\t \n   \t\t\t\t<p class=\"text-state\">{{_intl.joiningRoomLabel}}</p>\n   \t\t\t</section>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.CONNECTED_TO_ROOM || connectionUiState == ConnectionState.REQUESTING_CAMERA_ACCESS\">\n   \t\t\t\t<div class=\"spinner\">\n   \t\t\t\t\t<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xml:space=\"preserve\" x=\"0px\" y=\"0px\" viewBox=\"0 0 512 512\" width=\"100\" height=\"100\">\n   \t\t\t\t\t\t<g transform=\"translate(1, 42)\">\n   \t\t\t\t\t\t\t<path class=\"ring\" d=\"M277.334 1.088v-42.666c124.33 10.283 223.317 109.269 233.6 233.6h-42.666c-10.048-100.65-90.304-180.906-190.934-190.933zM234.667 425.579v42.666c-124.331-10.262-223.317-109.248-233.6-233.578h42.666c10.048 100.629 90.304 180.886 190.934 190.912zM43.755 192h-42.666c10.261-124.33 109.248-223.317 233.578-233.6v42.666c-100.63 10.048-180.886 90.304-190.912 190.934zM468.245 234.667h42.666c-10.262 124.331-109.248 223.317-233.579 233.6v-42.666c100.63-10.048 180.885-90.304 190.912-190.934z\" ></path>\n   \t\t\t\t\t\t\t<path class=\"segment\" d=\"M234.667 425.579v42.666c-124.331-10.262-223.317-109.248-233.6-233.578h42.666c10.048 100.629 90.304 180.886 190.934 190.912z\"></path>\n   \t\t\t\t\t\t</g>\n   \t\t\t\t\t</svg>\n   \t\t\t\t</div>\n   \t\t\t\t<p class=\"text-state\">{{_intl.loadingCameraLabel}}</p>\n   \t\t\t</section>\n\n   \t\t\t<section class=\"body\" *ngIf=\"connectionUiState == ConnectionState.CAMERA_ACCESS_DENIED\">\n   \t\t\t\t<h2>{{_intl.browserBlockingLabel}}</h2>\n\n   \t\t\t\t<figure>\n   \t\t\t\t\t<img src=\"https://d1x2efl61akomv.cloudfront.net/images/blocked-camera-chrome.4c7620aa.png\" height=\"38\">\n   \t\t\t\t</figure>\n\n   \t\t\t\t<p class=\"text\">{{_intl.browserBlockingExplainOneLabel}}</p>\n   \t\t\t\t<p class=\"text\">{{_intl.browserBlockingExplainTwoLabel}}</p>\n   \t\t\t</section>\n   \t\t</div>\n\n   \t\t<!-- GOODBYE MESSAGE -->\n   \t\t<div class=\"feedback-wrapper\" *ngIf=\"!session && !welcome\">\n   \t\t\t<div class=\"thank-you-message\">\n   \t\t\t\t<p class=\"body\">{{_intl.youLeftTheRoomLabel}}</p>\n   \t\t\t</div>\n   \t\t</div>\n\n   \t\t<div class=\"wrapper\" *ngIf=\"session && !welcome\">\n   \t\t\t<!-- SIDENAV -->\n   \t\t\t<md-sidenav-container>\n   \t\t\t\t<md-sidenav #sidenav align=\"end\" mode=\"side\" (close-start)=\"onSidenavCloseStart()\">\n   \t\t\t\t\t<div class=\"people\" *ngIf=\"showPeople\">\n   \t\t\t\t\t\t<button class=\"close\" (click)=\"togglePeople()\">\n   \t\t\t\t\t\t\t<md-icon>close</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t\t<h2>{{_intl.peopleLabel}}</h2>\n   \t\t\t\t\t\t<ul>\n   \t\t\t\t\t\t\t<li *ngFor=\"let key of participants | ObjNgFor\">\n   \t\t\t\t\t\t\t\t<p>\n   \t\t\t\t\t\t\t\t\t{{participants[key].getId()}}\n   \t\t\t\t\t\t\t\t</p>\n   \t\t\t\t\t\t\t</li>\n   \t\t\t\t\t\t</ul>\n   \t\t\t\t\t</div>\n   \t\t\t\t\t<div class=\"chat\" *ngIf=\"showChat\">\n   \t\t\t\t\t\t<button class=\"close\" (click)=\"toggleChat()\">\n   \t\t\t\t\t\t\t<md-icon>close</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t\t<h2>{{_intl.chatLabel}}</h2>\n   \t\t\t\t\t\t<ul>\n   \t\t\t\t\t\t\t<li *ngFor=\"let message of chatMessages\" [ngClass]=\"{'me': message.username == participantId}\">\n   \t\t\t\t\t\t\t\t<p>\n   \t\t\t\t\t\t\t\t\t{{message.message}}\n   \t\t\t\t\t\t\t\t</p>\n   \t\t\t\t\t\t\t</li>\n   \t\t\t\t\t\t</ul>\n   \t\t\t\t\t\t<div class=\"message-input-container\" (submit)=\"sendMessage(messageInput.value);\" accept-charset=\"UTF-8\">\n   \t\t\t\t\t\t\t<form>\n   \t\t\t\t\t\t\t\t<md-input-container color=\"primary\" floatPlaceholder=\"never\">\n   \t\t\t\t\t\t\t\t\t<input mdInput #messageInput placeholder=\"{{_intl.sendAMessageLabel}}\">\n   \t\t\t\t\t\t\t\t</md-input-container>\n   \t\t\t\t\t\t\t</form>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t</div>\n   \t\t\t\t</md-sidenav>\n\n   \t\t\t\t<div class=\"md-sidenav-content\">\n   \t\t\t\t\t<div class=\"panel\">\n   \t\t\t\t\t\t<horizontal-split-pane\n   \t\t\t\t\t\t\tprimary-component-minsize=\"50\"\n   \t\t\t\t\t\t\tsecondary-component-minsize=\"50\"\n   \t\t\t\t\t\t\tlocal-storage-key=\"split-pane\"\n   \t\t\t\t\t\t\tprimary-component-initialratio=\"0.5\"\n   \t\t\t\t\t\t\tsecondary-component-toggled-off=\"!showSecondaryContent\"\n   \t\t\t\t\t\t\t(on-change)=\"onChangeSplitPane()\">\n\n   \t\t\t\t\t\t\t<div class=\"split-pane-content-primary\">\n   \t\t\t\t\t\t\t\t<!-- PANEL VIDEO -->\n   \t\t\t\t\t\t\t\t<div #panelVideo class=\"panel-videos\">\n   \t\t\t\t\t\t\t\t\t<div class=\"stream-flex\">\n   \t\t\t\t\t\t\t\t\t\t<stream-gotomeeting #streamGoToMeeting *ngFor=\"let s of streams\" class=\"stream\" [stream]=\"s\"\n   \t\t\t\t\t\t\t\t\t\t\t[style.max-width]=\"streamMaxWidth\"\n   \t\t\t\t\t\t\t\t\t\t\t[style.max-height]=\"streamMaxHeight\"\n   \t\t\t\t\t\t\t\t\t\t\t(onSourceAdded)=\"handleOnSourceAdded($event)\">\n   \t\t\t\t\t\t\t\t\t\t</stream-gotomeeting>\n   \t\t\t\t\t\t\t\t\t</div>\n   \t\t\t\t\t\t\t\t</div>\n   \t\t\t\t\t\t\t</div>\n\n   \t\t\t\t\t\t\t<div class=\"split-pane-content-secondary\">\n   \t\t\t\t\t\t\t\t<!-- PANEL CONTENT -->\n   \t\t\t\t\t\t\t\t<div #panelContent class=\"panel-content\">\n   \t\t\t\t\t\t\t\t\t<ng-content></ng-content>\n   \t\t\t\t\t\t\t\t</div>\n   \t\t\t\t\t\t\t</div>\n\n   \t\t\t\t\t\t</horizontal-split-pane>\n   \t\t\t\t\t</div>\n\n   \t\t\t\t\t<!-- BUTTONS -->\n   \t\t\t\t\t<div class=\"buttons\">\n   \t\t\t\t\t\t<div class=\"up\">\n   \t\t\t\t\t\t\t<button md-button class=\"close-session\" (click)=\"leaveRoom()\" title=\"{{_intl.leaveRoomLabel}}\">\n   \t\t\t\t\t\t\t\t<md-icon>close</md-icon>\n   \t\t\t\t\t\t\t\t<div>{{_intl.leaveRoomLabel}}</div>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<button md-icon-button class=\"toggle-mic\" [ngClass]=\"{'disabled': !openviduApi.micEnabled}\" (click)=\"toggleMic()\" mdTooltip=\"{{(openviduApi.micEnabled) ? _intl.muteLabel : _intl.unmuteLabel}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t<md-icon>mic</md-icon>\n   \t\t\t\t\t\t\t\t<md-icon class=\"disabled-icon\">mic_off</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<button md-icon-button class=\"toggle-camera\" [ngClass]=\"{'disabled': !openviduApi.camEnabled}\" (click)=\"toggleCamera()\" mdTooltip=\"{{(openviduApi.micEnabled) ? _intl.videoOffLabel : _intl.videoOnLabel}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t<md-icon>videocam</md-icon>\n   \t\t\t\t\t\t\t\t<md-icon class=\"disabled-icon\">videocam_off</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t\t<hr />\n   \t\t\t\t\t\t<div class=\"middle\">\n   \t\t\t\t\t\t\t<button md-button class=\"show-people\" [ngClass]=\"{'active': showPeople}\" (click)=\"togglePeople()\" mdTooltip=\"{{_intl.peopleLabel}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t<md-icon>people</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<button md-button class=\"show-chat\" [ngClass]=\"{'active': showChat}\" (click)=\"toggleChat()\" mdTooltip=\"{{_intl.chatLabel}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t<md-icon>chat</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t\t<div class=\"bottom\">\n   \t\t\t\t\t\t\t<ng-container *ngFor=\"let option of toolbarOptions\">\n   \t\t\t\t\t\t\t\t<button md-button *ngIf=\"option.icon !== null\" (click)=\"option.onClick !== null && option.onClick()\" mdTooltip=\"{{(option.label) ? option.label : ''}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t\t<md-icon>{{option.icon}}</md-icon>\n   \t\t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t\n   \t\t\t\t\t\t\t<button md-button (click)=\"toggleFullscreen()\" *ngIf=\"!isFullscreen\" mdTooltip=\"{{_intl.fullscreenLabel}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t<md-icon>fullscreen</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t\t<button md-button (click)=\"toggleFullscreen()\" *ngIf=\"isFullscreen\" mdTooltip=\"{{_intl.exitFullscreenLabel}}\" mdTooltipPosition=\"left\">\n   \t\t\t\t\t\t\t\t<md-icon>clear</md-icon>\n   \t\t\t\t\t\t\t</button>\n   \t\t\t\t\t\t</div>\n   \t\t\t\t\t</div>\n   \t\t\t\t</div>\n\n   \t\t\t</md-sidenav-container>\n   \t\t</div>\n   \t</div>\n\t\t\n   </openvidu-template>\n\t",
        styles: ["\n   .openvidu-gotomeeting {\n     display: -webkit-box;\n     display: -webkit-flex;\n     display: -ms-flexbox;\n     display: flex;\n     -webkit-box-orient: vertical;\n     -webkit-box-direction: normal;\n     -webkit-flex-direction: column;\n         -ms-flex-direction: column;\n             flex-direction: column; }\n     .openvidu-gotomeeting.fullscreen {\n       width: 100%;\n       height: 100%; }\n     .openvidu-gotomeeting .spinner {\n       fill: #fd7a2b; }\n       .openvidu-gotomeeting .spinner .ring {\n         fill-opacity: 0.4; }\n       .openvidu-gotomeeting .spinner .segment {\n         -webkit-animation: chevron-segment .8s infinite step-end;\n                 animation: chevron-segment .8s infinite step-end;\n         -webkit-transform-origin: 110% -8%;\n             -ms-transform-origin: 110% -8%;\n                 transform-origin: 110% -8%; }\n     .openvidu-gotomeeting #welcome {\n       -webkit-box-flex: 1;\n       -webkit-flex: 1;\n           -ms-flex: 1;\n               flex: 1;\n       text-align: center;\n       color: #000;\n       margin: 5em auto auto;\n       max-width: 412px;\n       padding: 1em; }\n       .openvidu-gotomeeting #welcome header {\n         margin-bottom: 18px; }\n         .openvidu-gotomeeting #welcome header h1 {\n           margin: 0;\n           font-weight: 400;\n           line-height: 28px;\n           font-size: 20px; }\n       .openvidu-gotomeeting #welcome section {\n         padding: 0 0 2em 0; }\n         .openvidu-gotomeeting #welcome section .text-state {\n           font-size: 24px; }\n         .openvidu-gotomeeting #welcome section .text-body-main {\n           font-size: 18px; }\n         .openvidu-gotomeeting #welcome section .ui-button {\n           background: #ff2e63; }\n         .openvidu-gotomeeting #welcome section .ui-button, .openvidu-gotomeeting #welcome section .ui-button-invis, .openvidu-gotomeeting #welcome section .ui-button-outline {\n           display: inline-block;\n           border-radius: 3px;\n           border: solid 0;\n           -webkit-box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.15);\n                   box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.15);\n           cursor: pointer;\n           font-size: 14px;\n           padding: 10px 12px 10px 12px;\n           line-height: 20px;\n           text-decoration: none;\n           position: relative;\n           text-align: center;\n           margin-top: 4px;\n           margin-bottom: 4px;\n           outline: 0;\n           font-weight: 400;\n           word-wrap: break-word;\n           border: solid #ff2e63 0;\n           color: #fff;\n           -webkit-font-smoothing: subpixel-antialiased;\n           -moz-osx-font-smoothing: auto; }\n         .openvidu-gotomeeting #welcome section .video-preview-wrapper {\n           height: 256px;\n           background: rgba(0, 0, 0, 0.1);\n           overflow: hidden;\n           display: -webkit-box;\n           display: -webkit-flex;\n           display: -ms-flexbox;\n           display: flex;\n           -webkit-box-align: center;\n           -webkit-align-items: center;\n               -ms-flex-align: center;\n                   align-items: center;\n           -webkit-box-pack: center;\n           -webkit-justify-content: center;\n               -ms-flex-pack: center;\n                   justify-content: center;\n           -webkit-box-orient: vertical;\n           -webkit-box-direction: normal;\n           -webkit-flex-direction: column;\n               -ms-flex-direction: column;\n                   flex-direction: column; }\n         .openvidu-gotomeeting #welcome section .camera-off-icon md-icon {\n           height: 84px;\n           width: 500px; }\n           .openvidu-gotomeeting #welcome section .camera-off-icon md-icon .fill {\n             fill: #333; }\n     .openvidu-gotomeeting .feedback-wrapper {\n       -webkit-box-flex: 1;\n       -webkit-flex: 1;\n           -ms-flex: 1;\n               flex: 1;\n       text-align: center;\n       background-color: rgba(0, 0, 0, 0.5);\n       padding: 50px;\n       border-radius: 3px; }\n       .openvidu-gotomeeting .feedback-wrapper .thank-you-message {\n         font-size: 34px;\n         margin-top: .5em;\n         margin-bottom: 1.5em;\n         color: #fff; }\n       .openvidu-gotomeeting .feedback-wrapper p button {\n         background: #41cc8d; }\n     .openvidu-gotomeeting .wrapper {\n       -webkit-box-flex: 1;\n       -webkit-flex: 1;\n           -ms-flex: 1;\n               flex: 1;\n       display: -webkit-box;\n       display: -webkit-flex;\n       display: -ms-flexbox;\n       display: flex;\n       -webkit-box-orient: vertical;\n       -webkit-box-direction: normal;\n       -webkit-flex-direction: column;\n           -ms-flex-direction: column;\n               flex-direction: column;\n       background: #eee; }\n       .openvidu-gotomeeting .wrapper md-sidenav-container {\n         -webkit-box-flex: 1;\n         -webkit-flex: 1;\n             -ms-flex: 1;\n                 flex: 1;\n         background: transparent; }\n         .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content {\n           display: -webkit-box;\n           display: -webkit-flex;\n           display: -ms-flexbox;\n           display: flex;\n           -webkit-box-orient: horizontal;\n           -webkit-box-direction: normal;\n           -webkit-flex-direction: row;\n               -ms-flex-direction: row;\n                   flex-direction: row;\n           -webkit-box-align: stretch;\n           -webkit-align-items: stretch;\n               -ms-flex-align: stretch;\n                   align-items: stretch;\n           height: 100%; }\n           .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel {\n             -webkit-box-flex: 1;\n             -webkit-flex: 1;\n                 -ms-flex: 1;\n                     flex: 1;\n             display: -webkit-box;\n             display: -webkit-flex;\n             display: -ms-flexbox;\n             display: flex;\n             -webkit-box-orient: vertical;\n             -webkit-box-direction: normal;\n             -webkit-flex-direction: column;\n                 -ms-flex-direction: column;\n                     flex-direction: column; }\n             .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane {\n               -webkit-box-flex: 1;\n               -webkit-flex: 1;\n                   -ms-flex: 1;\n                       flex: 1;\n               display: -webkit-box;\n               display: -webkit-flex;\n               display: -ms-flexbox;\n               display: flex;\n               -webkit-box-orient: vertical;\n               -webkit-box-direction: normal;\n               -webkit-flex-direction: column;\n                   -ms-flex-direction: column;\n                       flex-direction: column; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane /deep/ .upper-component {\n                 display: -webkit-box;\n                 display: -webkit-flex;\n                 display: -ms-flexbox;\n                 display: flex; }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane /deep/ .upper-component .split-pane-content-primary {\n                   display: -webkit-box;\n                   display: -webkit-flex;\n                   display: -ms-flexbox;\n                   display: flex;\n                   -webkit-box-flex: 1;\n                   -webkit-flex: 1;\n                       -ms-flex: 1;\n                           flex: 1; }\n                   .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane /deep/ .upper-component .split-pane-content-primary .panel-videos {\n                     -webkit-box-flex: 1;\n                     -webkit-flex: 1;\n                         -ms-flex: 1;\n                             flex: 1;\n                     display: -webkit-box;\n                     display: -webkit-flex;\n                     display: -ms-flexbox;\n                     display: flex; }\n                     .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane /deep/ .upper-component .split-pane-content-primary .panel-videos .stream-flex {\n                       -webkit-box-flex: 1;\n                       -webkit-flex: 1;\n                           -ms-flex: 1;\n                               flex: 1;\n                       display: -webkit-box;\n                       display: -webkit-flex;\n                       display: -ms-flexbox;\n                       display: flex;\n                       -webkit-box-orient: horizontal;\n                       -webkit-box-direction: normal;\n                       -webkit-flex-direction: row;\n                           -ms-flex-direction: row;\n                               flex-direction: row;\n                       -webkit-align-content: center;\n                           -ms-flex-line-pack: center;\n                               align-content: center;\n                       -webkit-flex-wrap: wrap;\n                           -ms-flex-wrap: wrap;\n                               flex-wrap: wrap;\n                       -webkit-box-pack: center;\n                       -webkit-justify-content: center;\n                           -ms-flex-pack: center;\n                               justify-content: center; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane /deep/ .lower-component .split-pane-content-secondary {\n                 display: -webkit-box;\n                 display: -webkit-flex;\n                 display: -ms-flexbox;\n                 display: flex;\n                 -webkit-box-flex: 1;\n                 -webkit-flex: 1;\n                     -ms-flex: 1;\n                         flex: 1; }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .panel horizontal-split-pane /deep/ .lower-component .split-pane-content-secondary .panel-content {\n                   -webkit-box-flex: 1;\n                   -webkit-flex: 1;\n                       -ms-flex: 1;\n                           flex: 1; }\n           .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons {\n             background: #485163;\n             color: #fff; }\n             .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons hr {\n               width: 84%;\n               margin: 10px auto -1px;\n               border-top: none;\n               border-bottom: 1px solid rgba(255, 255, 255, 0.4); }\n             .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button {\n               display: block;\n               padding: 8px 8px;\n               -webkit-box-sizing: border-box;\n                       box-sizing: border-box;\n               text-align: center;\n               font-size: 12px; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.close-session {\n                 background-color: #EAECEC;\n                 margin-bottom: 16px;\n                 color: #E15E52; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.toggle-mic, .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.toggle-camera {\n                 background-color: #01B17B;\n                 border-color: #86E098;\n                 -webkit-box-shadow: 0 0 25px 0 #01B17B;\n                         box-shadow: 0 0 25px 0 #01B17B;\n                 padding: 0px;\n                 margin: 16px auto; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.disabled {\n                 background-color: #fa5412;\n                 border-color: #ff9673;\n                 -webkit-box-shadow: 0 1px 2px rgba(51, 51, 51, 0.4);\n                         box-shadow: 0 1px 2px rgba(51, 51, 51, 0.4); }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.disabled md-icon {\n                   display: none; }\n                   .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.disabled md-icon.disabled-icon {\n                     display: inline-block; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button.active {\n                 background-color: #eaecec;\n                 color: #546075; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button md-icon {\n                 display: inline-block; }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button md-icon.disabled-icon {\n                   display: none; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container .md-sidenav-content .buttons button div {\n                 line-height: 20px; }\n         .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav {\n           display: -webkit-box;\n           display: -webkit-flex;\n           display: -ms-flexbox;\n           display: flex;\n           background: #eaecec;\n           min-width: 250px; }\n           .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .close {\n             background: transparent;\n             outline: none;\n             border: none;\n             position: absolute;\n             top: 10px;\n             right: 10px;\n             cursor: pointer; }\n           .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav h2 {\n             display: inline-block;\n             margin-bottom: 22px;\n             margin-left: 20px;\n             font-size: 28px;\n             color: #546075; }\n           .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .people {\n             -webkit-box-flex: 1;\n             -webkit-flex: 1;\n                 -ms-flex: 1;\n                     flex: 1; }\n             .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .people ul {\n               padding: 0px;\n               overflow: auto; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .people ul li {\n                 display: -webkit-box;\n                 display: -webkit-flex;\n                 display: -ms-flexbox;\n                 display: flex;\n                 -webkit-box-orient: horizontal;\n                 -webkit-box-direction: normal;\n                 -webkit-flex-direction: row;\n                     -ms-flex-direction: row;\n                         flex-direction: row;\n                 -webkit-box-pack: start;\n                 -webkit-justify-content: flex-start;\n                     -ms-flex-pack: start;\n                         justify-content: flex-start;\n                 padding: 0px 10px;\n                 border-bottom: 1px solid #bfbfbf; }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .people ul li:first-child {\n                   border-top: 1px solid #bfbfbf; }\n           .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat {\n             -webkit-box-flex: 1;\n             -webkit-flex: 1;\n                 -ms-flex: 1;\n                     flex: 1;\n             display: -webkit-box;\n             display: -webkit-flex;\n             display: -ms-flexbox;\n             display: flex;\n             -webkit-box-orient: vertical;\n             -webkit-box-direction: normal;\n             -webkit-flex-direction: column;\n                 -ms-flex-direction: column;\n                     flex-direction: column;\n             -webkit-box-pack: end;\n             -webkit-justify-content: flex-end;\n                 -ms-flex-pack: end;\n                     justify-content: flex-end; }\n             .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat ul {\n               -webkit-box-flex: 1;\n               -webkit-flex: 1;\n                   -ms-flex: 1;\n                       flex: 1;\n               padding: 0px 10px 0px 10px;\n               overflow: auto; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat ul li {\n                 display: -webkit-box;\n                 display: -webkit-flex;\n                 display: -ms-flexbox;\n                 display: flex;\n                 -webkit-box-orient: horizontal;\n                 -webkit-box-direction: normal;\n                 -webkit-flex-direction: row;\n                     -ms-flex-direction: row;\n                         flex-direction: row;\n                 -webkit-box-pack: start;\n                 -webkit-justify-content: flex-start;\n                     -ms-flex-pack: start;\n                         justify-content: flex-start;\n                 padding: 6px 14px; }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat ul li.me {\n                   -webkit-box-orient: horizontal;\n                   -webkit-box-direction: reverse;\n                   -webkit-flex-direction: row-reverse;\n                       -ms-flex-direction: row-reverse;\n                           flex-direction: row-reverse; }\n                   .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat ul li.me p {\n                     background-color: #caf3b5; }\n                 .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat ul li p {\n                   background-color: #f5fcf9;\n                   margin: 0;\n                   margin-right: 20px;\n                   padding: 7px 8px 6px;\n                   font-size: 12px;\n                   line-height: 1.3333;\n                   background-color: #f5fcf9;\n                   border-radius: 3px;\n                   word-wrap: break-word;\n                   max-width: -webkit-calc(100% - 68px);\n                   max-width: calc(100% - 68px);\n                   color: rgba(0, 0, 0, 0.87); }\n             .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat .message-input-container {\n               background: #fff;\n               padding: 0px 10px; }\n               .openvidu-gotomeeting .wrapper md-sidenav-container md-sidenav .chat .message-input-container md-input-container {\n                 width: 100%; }\n\n   @-webkit-keyframes spin {\n     from {\n       -webkit-transform: rotate(0);\n               transform: rotate(0); }\n     to {\n       -webkit-transform: rotate(360deg);\n               transform: rotate(360deg); } }\n\n   @keyframes spin {\n     from {\n       -webkit-transform: rotate(0);\n               transform: rotate(0); }\n     to {\n       -webkit-transform: rotate(360deg);\n               transform: rotate(360deg); } }\n\n   @-webkit-keyframes chevron-segment {\n     0% {\n       -webkit-transform: rotate(0deg);\n               transform: rotate(0deg); }\n     25% {\n       -webkit-transform: rotate(90deg);\n               transform: rotate(90deg); }\n     50% {\n       -webkit-transform: rotate(180deg);\n               transform: rotate(180deg); }\n     75% {\n       -webkit-transform: rotate(270deg);\n               transform: rotate(270deg); }\n     100% {\n       -webkit-transform: rotate(0deg);\n               transform: rotate(0deg); } }\n\n   @keyframes chevron-segment {\n     0% {\n       -webkit-transform: rotate(0deg);\n               transform: rotate(0deg); }\n     25% {\n       -webkit-transform: rotate(90deg);\n               transform: rotate(90deg); }\n     50% {\n       -webkit-transform: rotate(180deg);\n               transform: rotate(180deg); }\n     75% {\n       -webkit-transform: rotate(270deg);\n               transform: rotate(270deg); }\n     100% {\n       -webkit-transform: rotate(0deg);\n               transform: rotate(0deg); } }\n\t"]
    }),
    __metadata("design:paramtypes", [core_1.Renderer2, angular_bigscreen_1.BigScreenService,
        openvidu_gotomeeting_intl_1.OpenViduGoToMeetingIntl])
], OpenViduGoToMeetingComponent);
exports.OpenViduGoToMeetingComponent = OpenViduGoToMeetingComponent;
