import { ElementRef, EventEmitter, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { MdDialog, MdSidenav } from '@angular/material';
import { BigScreenService } from 'angular-bigscreen';
import { Connection, Stream } from 'openvidu-browser';
import { OpenViduDirective, CameraAccessEvent, ErrorEvent, MessageEvent, ParticipantEvent, RoomConnectedEvent, StreamEvent } from '../openvidu.directive';
import { OpenViduHangoutsIntl } from './openvidu-hangouts-intl';
export interface ToolbarOption {
    label?: string;
    icon: string;
    onClick?: Function;
}
export declare enum OpenViduNotificationType {
    MIC_CHANGED = 1,
    CAM_CHANGED = 2,
}
export declare class OpenViduHangoutsComponent implements OnInit, OnDestroy {
    private renderer;
    private bigScreenService;
    _intl: OpenViduHangoutsIntl;
    dialog: MdDialog;
    wsUrl: string;
    sessionId: string;
    participantId: string;
    apiKey: string;
    token: string;
    toolbarOptions: ToolbarOption[];
    onRoomConnected: EventEmitter<void>;
    onErrorRoom: EventEmitter<any>;
    onRoomClosed: EventEmitter<void>;
    onLostConnection: EventEmitter<any>;
    onParticipantJoined: EventEmitter<any>;
    onParticipantLeft: EventEmitter<any>;
    onNewMessage: EventEmitter<any>;
    onErrorMedia: EventEmitter<any>;
    onLeaveRoom: EventEmitter<void>;
    onCustomNotification: EventEmitter<any>;
    openviduApi: OpenViduDirective;
    mainElement: ElementRef;
    sidenav: MdSidenav;
    messageInput: ElementRef;
    userMessage: string;
    isFullscreen: boolean;
    micOffParticipants: Connection[];
    camOffParticipants: Connection[];
    mainStream: Stream;
    streams: Stream[];
    chatMessages: any[];
    chatButtonState: string;
    private session;
    private participants;
    private myCamera;
    constructor(renderer: Renderer2, bigScreenService: BigScreenService, _intl: OpenViduHangoutsIntl, dialog: MdDialog);
    ngOnInit(): void;
    ngOnDestroy(): void;
    toggleMic(): void;
    toggleCamera(): void;
    toggleFullscreen(): void;
    toggleChat(): void;
    openSettings(): void;
    onSidenavOpenStart(): void;
    onSidenavCloseStart(): void;
    sendMessage(text: string): void;
    sendCustomNotification(obj: any, callback: any): void;
    leaveRoom(): void;
    handleOnUpdateMainSpeaker(streamEvent: StreamEvent): void;
    handleOnServerConnected(): void;
    handleOnErrorServer(errorEvent: ErrorEvent): void;
    handleOnRoomConnected(roomConnectedEvent: RoomConnectedEvent): void;
    handleOnErrorRoom(): void;
    handleOnCameraAccessChange(cameraEvent: CameraAccessEvent): void;
    handleOnRoomClosed(): void;
    handleOnLostConnection(): void;
    handleOnParticipantJoined(participantEvent: ParticipantEvent): void;
    handleOnParticipantLeft(participantEvent: ParticipantEvent): void;
    handleOnErrorMedia(errorEvent: ErrorEvent): void;
    handleOnStreamAdded(streamEvent: StreamEvent): void;
    handleOnStreamRemoved(streamEvent: StreamEvent): void;
    handleOnLeaveRoom(): void;
    handleOnNewMessage(messageEvent: MessageEvent): void;
    handleOnCustomNotification(obj: any): void;
    private setUserMessage(msg);
}
