"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
// Angular Material
var animations_1 = require("@angular/animations");
var material_1 = require("@angular/material");
// Fullscreen Service
var angular_bigscreen_1 = require("angular-bigscreen");
// OpenVidu Directive
var openvidu_directive_1 = require("../openvidu.directive");
// i18n Labels and Messages
var openvidu_hangouts_intl_1 = require("./openvidu-hangouts-intl");
// OpenVidu Hangouts Dialog
var dialog_hangouts_component_1 = require("./dialog-hangouts/dialog-hangouts.component");
var OpenViduNotificationType;
(function (OpenViduNotificationType) {
    OpenViduNotificationType[OpenViduNotificationType["MIC_CHANGED"] = 1] = "MIC_CHANGED";
    OpenViduNotificationType[OpenViduNotificationType["CAM_CHANGED"] = 2] = "CAM_CHANGED";
})(OpenViduNotificationType = exports.OpenViduNotificationType || (exports.OpenViduNotificationType = {}));
;
var OpenViduHangoutsComponent = (function () {
    function OpenViduHangoutsComponent(renderer, bigScreenService, _intl, dialog) {
        this.renderer = renderer;
        this.bigScreenService = bigScreenService;
        this._intl = _intl;
        this.dialog = dialog;
        // Unique Inputs
        // To set new options in menu
        this.toolbarOptions = [];
        // Outputs
        this.onRoomConnected = new core_1.EventEmitter();
        this.onErrorRoom = new core_1.EventEmitter();
        this.onRoomClosed = new core_1.EventEmitter();
        this.onLostConnection = new core_1.EventEmitter();
        this.onParticipantJoined = new core_1.EventEmitter();
        this.onParticipantLeft = new core_1.EventEmitter();
        this.onNewMessage = new core_1.EventEmitter();
        this.onErrorMedia = new core_1.EventEmitter();
        this.onLeaveRoom = new core_1.EventEmitter();
        this.onCustomNotification = new core_1.EventEmitter();
        // Flags for HTML elements
        this.userMessage = '';
        this.isFullscreen = false;
        // Participnats who have enabled/disabled their mic
        this.micOffParticipants = [];
        // Participnats who have enabled/disabled their cam
        this.camOffParticipants = [];
        // Rest of peers
        this.streams = [];
        // Chat
        this.chatMessages = [];
        // Animations
        this.chatButtonState = 'show';
        // Participants
        this.participants = {};
        this.setUserMessage(this._intl.loadingLabel);
    }
    OpenViduHangoutsComponent.prototype.ngOnInit = function () {
        var _this = this;
        // Display message
        this.setUserMessage(this._intl.connectingLabel);
        // Set fullscreen listener
        this.bigScreenService.onChange(function () {
            // No need to check if mainElement is the one with fullscreen
            _this.isFullscreen = _this.bigScreenService.isFullscreen();
        });
    };
    OpenViduHangoutsComponent.prototype.ngOnDestroy = function () {
        this.bigScreenService.exit();
        this.leaveRoom();
    };
    /*---------------------*/
    /* GUI RELATED METHODS */
    /*---------------------*/
    OpenViduHangoutsComponent.prototype.toggleMic = function () {
        this.openviduApi.micEnabled = !this.openviduApi.micEnabled;
    };
    OpenViduHangoutsComponent.prototype.toggleCamera = function () {
        this.openviduApi.camEnabled = !this.openviduApi.camEnabled;
    };
    OpenViduHangoutsComponent.prototype.toggleFullscreen = function () {
        if (this.bigScreenService.isFullscreen()) {
            this.bigScreenService.exit();
        }
        else {
            this.bigScreenService.request(this.mainElement.nativeElement);
        }
    };
    OpenViduHangoutsComponent.prototype.toggleChat = function () {
        this.sidenav.toggle();
    };
    OpenViduHangoutsComponent.prototype.openSettings = function () {
        var _this = this;
        var dialogRef = this.dialog.open(dialog_hangouts_component_1.DialogHangoutsComponent);
        // On change video input
        dialogRef.afterClosed().subscribe(function (result) {
            if (result) {
                _this.openviduApi.setCamera(result);
            }
            else {
                console.log('No camera selected');
            }
        });
    };
    OpenViduHangoutsComponent.prototype.onSidenavOpenStart = function () {
        this.chatButtonState = 'hide';
    };
    OpenViduHangoutsComponent.prototype.onSidenavCloseStart = function () {
        this.chatButtonState = 'show';
    };
    OpenViduHangoutsComponent.prototype.sendMessage = function (text) {
        // Clean input
        this.messageInput.nativeElement.value = null;
        //this.renderer.setValue(this.messageInput, null);
        // Send to OpenVidu server
        this.openviduApi.sendMessage(text);
    };
    OpenViduHangoutsComponent.prototype.sendCustomNotification = function (obj, callback) {
        this.openviduApi.sendCustomNotification(obj, callback);
    };
    OpenViduHangoutsComponent.prototype.leaveRoom = function () {
        // Reset
        this.mainStream = null;
        this.streams = [];
        this.chatMessages = [];
        this.chatButtonState = 'show';
        this.session = null;
        this.participants = {};
        // Display message
        this.setUserMessage(this._intl.youLeftTheRoomLabel);
        this.openviduApi.leaveRoom();
    };
    /*------------------------*/
    /* HANDLE OPENVIDU EVENTS */
    /*------------------------*/
    OpenViduHangoutsComponent.prototype.handleOnUpdateMainSpeaker = function (streamEvent) {
        // Check if stream exists
        if (this.streams.indexOf(streamEvent.stream) < 0) {
            this.streams.push(streamEvent.stream);
        }
        // Set main stream
        this.mainStream = streamEvent.stream;
        // Check if participant exists
        if (!this.participants[this.mainStream.getParticipant().getId()]) {
            this.participants[this.mainStream.getParticipant().getId()] = this.mainStream.getParticipant();
        }
    };
    OpenViduHangoutsComponent.prototype.handleOnServerConnected = function () {
        this.setUserMessage(this._intl.connectingToRoomLabel);
    };
    OpenViduHangoutsComponent.prototype.handleOnErrorServer = function (errorEvent) {
        if (errorEvent.error) {
            this.setUserMessage(errorEvent.error.message);
        }
    };
    OpenViduHangoutsComponent.prototype.handleOnRoomConnected = function (roomConnectedEvent) {
        if (roomConnectedEvent && roomConnectedEvent.session) {
            this.session = roomConnectedEvent.session;
        }
        // Emit event
        this.onRoomConnected.emit();
    };
    OpenViduHangoutsComponent.prototype.handleOnErrorRoom = function () {
        this.setUserMessage(this._intl.errorRoom);
        // Emit event
        this.onErrorRoom.emit();
    };
    OpenViduHangoutsComponent.prototype.handleOnCameraAccessChange = function (cameraEvent) {
        if (cameraEvent.access) {
            // All good :)
            this.myCamera = cameraEvent.camera;
            if (this.streams.indexOf(this.myCamera) < 0) {
                this.streams.push(this.myCamera);
            }
        }
        else if (!cameraEvent.access) {
            // No camera :(
        }
    };
    OpenViduHangoutsComponent.prototype.handleOnRoomClosed = function () {
        this.session = null;
        // Emit event
        this.onRoomClosed.emit();
    };
    OpenViduHangoutsComponent.prototype.handleOnLostConnection = function () {
        if (!this.session) {
            // Emit event
            this.onLostConnection.emit({
                error: new Error('Lost connection with the server')
            });
        }
        else {
            // Emit event
            this.onLostConnection.emit();
        }
    };
    OpenViduHangoutsComponent.prototype.handleOnParticipantJoined = function (participantEvent) {
        var newParticipant = participantEvent.participant;
        this.participants[newParticipant.getId()] = newParticipant;
        // Emit event
        this.onParticipantJoined.emit({
            participantId: newParticipant.getId()
        });
    };
    OpenViduHangoutsComponent.prototype.handleOnParticipantLeft = function (participantEvent) {
        var oldParticipant = participantEvent.participant;
        delete this.participants[oldParticipant.getId()];
        // Emit event
        this.onParticipantLeft.emit({
            participantId: oldParticipant.getId()
        });
    };
    OpenViduHangoutsComponent.prototype.handleOnErrorMedia = function (errorEvent) {
        // Emit event
        this.onErrorMedia.emit({
            error: errorEvent.error
        });
    };
    OpenViduHangoutsComponent.prototype.handleOnStreamAdded = function (streamEvent) {
        var newStream = streamEvent.stream;
        if (this.streams.indexOf(newStream) < 0) {
            this.streams.push(newStream);
        }
    };
    OpenViduHangoutsComponent.prototype.handleOnStreamRemoved = function (streamEvent) {
        var oldStream = streamEvent.stream;
        this.streams.splice(this.streams.indexOf(oldStream), 1);
    };
    OpenViduHangoutsComponent.prototype.handleOnLeaveRoom = function () {
        // Emit event
        this.onLeaveRoom.emit();
    };
    OpenViduHangoutsComponent.prototype.handleOnNewMessage = function (messageEvent) {
        // Fix: to get usernam
        var dataObj = JSON.parse(messageEvent.participant.data);
        // Handle message
        this.chatMessages.push({
            username: dataObj.username,
            message: messageEvent.message,
            date: new Date() // Use current date
        });
        this.onNewMessage.emit(messageEvent);
    };
    OpenViduHangoutsComponent.prototype.handleOnCustomNotification = function (obj) {
        if (obj.openviduType) {
            // TODO: Internal custom notification
            switch (obj.openviduType) {
                case OpenViduNotificationType.MIC_CHANGED:
                    if (obj.micEnabled) {
                        // Remove participant from micOffParticipant
                    }
                    else {
                        // Add participant to micOffParticipant
                    }
                    break;
                case OpenViduNotificationType.CAM_CHANGED:
                    if (obj.micEnabled) {
                        // Remove participant from camOffParticipant
                    }
                    else {
                        // Add participant to camOffParticipant
                    }
                    break;
            }
        }
        else {
            this.onCustomNotification.emit(obj);
        }
    };
    /*-----------------*/
    /* PRIVATE METHODS */
    /*-----------------*/
    OpenViduHangoutsComponent.prototype.setUserMessage = function (msg) {
        this.userMessage = msg;
    };
    return OpenViduHangoutsComponent;
}());
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduHangoutsComponent.prototype, "wsUrl", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduHangoutsComponent.prototype, "sessionId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduHangoutsComponent.prototype, "participantId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduHangoutsComponent.prototype, "apiKey", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduHangoutsComponent.prototype, "token", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", Array)
], OpenViduHangoutsComponent.prototype, "toolbarOptions", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onRoomConnected", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onErrorRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onRoomClosed", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onLostConnection", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onParticipantJoined", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onParticipantLeft", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onNewMessage", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onErrorMedia", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onLeaveRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduHangoutsComponent.prototype, "onCustomNotification", void 0);
__decorate([
    core_1.ViewChild('openviduApi'),
    __metadata("design:type", openvidu_directive_1.OpenViduDirective)
], OpenViduHangoutsComponent.prototype, "openviduApi", void 0);
__decorate([
    core_1.ViewChild('main'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduHangoutsComponent.prototype, "mainElement", void 0);
__decorate([
    core_1.ViewChild('sidenav'),
    __metadata("design:type", material_1.MdSidenav)
], OpenViduHangoutsComponent.prototype, "sidenav", void 0);
__decorate([
    core_1.ViewChild('messageInput'),
    __metadata("design:type", core_1.ElementRef)
], OpenViduHangoutsComponent.prototype, "messageInput", void 0);
OpenViduHangoutsComponent = __decorate([
    core_1.Component({
        selector: 'openvidu, openvidu-hangouts',
        template: "\n   <openvidu-template\n   \t#openviduApi=\"openviduApi\"\n   \t[wsUrl]=\"wsUrl\"\n   \t[sessionId]=\"sessionId\"\n   \t[participantId]=\"participantId\"\n\t\n   \t(onUpdateMainSpeaker)=\"handleOnUpdateMainSpeaker($event)\"\n\t\n   \t(onServerConnected)=\"handleOnServerConnected($event)\"\n   \t(onErrorServer)=\"handleOnErrorServer($event)\"\n   \t(onRoomConnected)=\"handleOnRoomConnected($event)\"\n   \t(onErrorRoom)=\"handleOnErrorRoom($event)\"\n   \t(onCameraAccessChange)=\"handleOnCameraAccessChange($event)\"\n\t\n   \t(onParticipantJoined)=\"handleOnParticipantJoined($event)\"\n   \t(onParticipantLeft)=\"handleOnParticipantLeft($event)\"\n\t\n   \t(onStreamAdded)=\"handleOnStreamAdded($event)\"\n   \t(onStreamRemoved)=\"handleOnStreamRemoved($event)\"\n\t\n   \t(onErrorMedia)=\"handleOnErrorMedia()\"\n   \t(onLeaveRoom)=\"handleOnLeaveRoom()\"\n   \t(onNewMessage)=\"handleOnNewMessage($event)\"\n   \t(onCustomNotification)=\"handleOnCustomNotification($event)\">\n\t\n   \t<div #main class=\"openvidu-hangouts\">\n\n   \t\t<!-- Messages to user -->\n   \t\t<div class=\"message-screen\" *ngIf=\"userMessage && !session\">\n   \t\t\t{{userMessage}}\n   \t\t</div>\n\n   \t\t<!-- VIDEO CHAT -->\n   \t\t<div class=\"wrapper\" *ngIf=\"session\">\n\n   \t\t\t<!-- TOOLBAR -->\n   \t\t\t<div class=\"toolbar\">\n   \t\t\t\t<md-toolbar color=\"primary\">\n   \t\t\t\t\t<span>{{sessionId}}</span>\n   \t\t\t\t\t<span class=\"example-spacer\"></span>\n\n   \t\t\t\t\t<ng-container *ngFor=\"let option of toolbarOptions\">\n   \t\t\t\t\t\t<button md-icon-button *ngIf=\"option.icon !== null\" (click)=\"option.onClick !== null && option.onClick()\" mdTooltip=\"{{(option.label) ? option.label : ''}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t\t<md-icon>{{option.icon}}</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t</ng-container>\n\t\t\t\t\t\n   \t\t\t\t\t<!-- Settings -->\n   \t\t\t\t\t<button md-icon-button (click)=\"openSettings()\" *ngIf=\"!isFullscreen\" mdTooltip=\"{{_intl.settingsLabel}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t<md-icon>settings</md-icon>\n   \t\t\t\t\t</button>\n\t\t\t\t\t\n   \t\t\t\t\t<!-- For fullscreen -->\n   \t\t\t\t\t<button md-icon-button (click)=\"toggleFullscreen()\" *ngIf=\"!isFullscreen\" mdTooltip=\"{{_intl.fullscreenLabel}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t<md-icon>fullscreen</md-icon>\n   \t\t\t\t\t</button>\n   \t\t\t\t\t<button md-icon-button (click)=\"toggleFullscreen()\" *ngIf=\"isFullscreen\" mdTooltip=\"{{_intl.exitFullscreenLabel}}\" mdTooltipPosition=\"below\">\n   \t\t\t\t\t\t<md-icon>clear</md-icon>\n   \t\t\t\t\t</button>\n   \t\t\t\t</md-toolbar>\n   \t\t\t</div>\n\n   \t\t\t<!-- CHAT -->\n   \t\t\t<md-sidenav-container>\n   \t\t\t\t<md-sidenav #sidenav mode=\"side\" (open-start)=\"onSidenavOpenStart()\" (close-start)=\"onSidenavCloseStart()\">\n   \t\t\t\t\t<div class=\"messages\">\n   \t\t\t\t\t\t<ul>\n   \t\t\t\t\t\t\t<li *ngFor=\"let message of chatMessages\">\n   \t\t\t\t\t\t\t\t<div>\n   \t\t\t\t\t\t\t\t\t<span>{{(message.username == participantId) ? 'You' : message.username}}</span>\n   \t\t\t\t\t\t\t\t\t{{message.message}}\n   \t\t\t\t\t\t\t\t</div>\n   \t\t\t\t\t\t\t\t<span class=\"date\">{{message.date | date: 'H:m'}}</span>\n   \t\t\t\t\t\t\t</li>\n   \t\t\t\t\t\t</ul>\n   \t\t\t\t\t</div>\n   \t\t\t\t\t<div class=\"bottom\" (submit)=\"sendMessage(messageInput.value);\" accept-charset=\"UTF-8\">\n   \t\t\t\t\t\t<button md-fab class=\"close-chat transparent-button\" (click)=\"toggleChat()\"><md-icon>arrow_back</md-icon></button>\n   \t\t\t\t\t\t<form>\n   \t\t\t\t\t\t\t<md-input-container color=\"primary\" floatPlaceholder=\"never\">\n   \t\t\t\t\t\t\t\t<input mdInput #messageInput placeholder=\"Send a message\">\n   \t\t\t\t\t\t\t</md-input-container>\n   \t\t\t\t\t\t\t<button #sendMessageButton md-fab type=\"submit\" class=\"send-message transparent-button\" [disabled]=\"messageInput.value.length == 0\" [class.enabled]=\"messageInput.value.length > 0\"><md-icon>send</md-icon></button>\n   \t\t\t\t\t\t</form>\n   \t\t\t\t\t</div>\n   \t\t\t\t</md-sidenav>\n\n   \t\t\t\t<!-- MAIN VIDEO -->\n   \t\t\t\t<div class=\"main-video\">\n   \t\t\t\t\t<div class=\"message\" *ngIf=\"streams.length == 1\">You are alone in this room :(</div>\n   \t\t\t\t\t<stream-hangouts class=\"main-stream\" *ngIf=\"mainStream != null && mainStream.getWrStream() != null\" [stream]=\"mainStream\"></stream-hangouts>\n   \t\t\t\t\t<div class=\"name-placeholder\" *ngIf=\"mainStream == null || mainStream.getWrStream() == null\">\n   \t\t\t\t\t\t<div *ngIf=\"mainStream != null\">{{JSON.parse(mainStream.getParticipant().data).username.charAt(0)}}</div>\n   \t\t\t\t\t\t<div *ngIf=\"mainStream == null && participantId != null\">{{participantId.charAt(0)}}</div>\n   \t\t\t\t\t</div>\n   \t\t\t\t</div>\n\n   \t\t\t\t<!-- BUTTONS & OTHERS VIDEOS -->\n   \t\t\t\t<div class=\"bottom-bar\">\n   \t\t\t\t\t<div class=\"buttons\">\n   \t\t\t\t\t\t<button md-fab class=\"toggle-mic\" [ngClass]=\"{'disabled': !openviduApi.micEnabled}\" (click)=\"toggleMic()\">\n   \t\t\t\t\t\t\t<md-icon>mic</md-icon>\n   \t\t\t\t\t\t\t<md-icon class=\"disabled-icon\">mic_off</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t\t<button md-fab class=\"close-session\" (click)=\"leaveRoom()\">\n   \t\t\t\t\t\t\t<md-icon>call_end</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t\t<button md-fab class=\"toggle-camera\" [ngClass]=\"{'disabled': !openviduApi.camEnabled}\" (click)=\"toggleCamera()\">\n   \t\t\t\t\t\t\t<md-icon>videocam</md-icon>\n   \t\t\t\t\t\t\t<md-icon class=\"disabled-icon\">videocam_off</md-icon>\n   \t\t\t\t\t\t</button>\n   \t\t\t\t\t</div>\n   \t\t\t\t\t<div class=\"streams\" *ngIf=\"streams.length > 1\">\n   \t\t\t\t\t\t<stream-hangouts class=\"stream side-stream\" [stream]=\"myCamera\" [ngClass]=\"{'hide-video': (myCamera === mainStream)}\">\n\n   \t\t\t\t\t\t</stream-hangouts>\n   \t\t\t\t\t\t<ng-container *ngFor=\"let s of streams\">\n   \t\t\t\t\t\t\t<stream-hangouts class=\"stream side-stream square\"\n   \t\t\t\t\t\t\t\t*ngIf=\"(s !== myCamera)\"\n   \t\t\t\t\t\t\t\t[stream]=\"s\"\n   \t\t\t\t\t\t\t\t[ngClass]=\"{'hide-video': (s === mainStream), 'mic-off': micOffParticipants.indexOf(s.getParticipant()) >= 0, 'cam-off': camOffParticipants.indexOf(s.getParticipant()) >= 0}\">\n\n   \t\t\t\t\t\t\t</stream-hangouts>\n   \t\t\t\t\t\t</ng-container>\n   \t\t\t\t\t</div>\n   \t\t\t\t</div>\n\n   \t\t\t\t<button md-fab class=\"toggle-chat\" (click)=\"toggleChat()\" [@chatButtonAnimation]=\"chatButtonState\">\n   \t\t\t\t\t<md-icon>chat</md-icon>\n   \t\t\t\t</button>\n   \t\t\t</md-sidenav-container>\n\n   \t\t</div>\n   \t</div>\n   </openvidu-template>\n\t",
        styles: ["\n   /**\n    * Applies styles for users in high contrast mode. Note that this only applies\n    * to Microsoft browsers. Chrome can be included by checking for the `html[hc]`\n    * attribute, however Chrome handles high contrast differently.\n    */\n   /* Theme for the ripple elements.*/\n   /** The mixins below are shared between md-menu and md-select */\n   /**\n    * This mixin adds the correct panel transform styles based\n    * on the direction that the menu panel opens.\n    */\n   /* stylelint-disable material/no-prefixes */\n   /* stylelint-enable */\n   /**\n    * Applies styles for users in high contrast mode. Note that this only applies\n    * to Microsoft browsers. Chrome can be included by checking for the `html[hc]`\n    * attribute, however Chrome handles high contrast differently.\n    */\n   /**\n    * This mixin contains shared option styles between the select and\n    * autocomplete components.\n    */\n   .mat-elevation-z0 {\n     -webkit-box-shadow: 0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z1 {\n     -webkit-box-shadow: 0px 2px 1px -1px rgba(0, 0, 0, 0.2), 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 1px 3px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 2px 1px -1px rgba(0, 0, 0, 0.2), 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 1px 3px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z2 {\n     -webkit-box-shadow: 0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z3 {\n     -webkit-box-shadow: 0px 3px 3px -2px rgba(0, 0, 0, 0.2), 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 1px 8px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 3px 3px -2px rgba(0, 0, 0, 0.2), 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 1px 8px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z4 {\n     -webkit-box-shadow: 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z5 {\n     -webkit-box-shadow: 0px 3px 5px -1px rgba(0, 0, 0, 0.2), 0px 5px 8px 0px rgba(0, 0, 0, 0.14), 0px 1px 14px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 3px 5px -1px rgba(0, 0, 0, 0.2), 0px 5px 8px 0px rgba(0, 0, 0, 0.14), 0px 1px 14px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z6 {\n     -webkit-box-shadow: 0px 3px 5px -1px rgba(0, 0, 0, 0.2), 0px 6px 10px 0px rgba(0, 0, 0, 0.14), 0px 1px 18px 0px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 3px 5px -1px rgba(0, 0, 0, 0.2), 0px 6px 10px 0px rgba(0, 0, 0, 0.14), 0px 1px 18px 0px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z7 {\n     -webkit-box-shadow: 0px 4px 5px -2px rgba(0, 0, 0, 0.2), 0px 7px 10px 1px rgba(0, 0, 0, 0.14), 0px 2px 16px 1px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 4px 5px -2px rgba(0, 0, 0, 0.2), 0px 7px 10px 1px rgba(0, 0, 0, 0.14), 0px 2px 16px 1px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z8 {\n     -webkit-box-shadow: 0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z9 {\n     -webkit-box-shadow: 0px 5px 6px -3px rgba(0, 0, 0, 0.2), 0px 9px 12px 1px rgba(0, 0, 0, 0.14), 0px 3px 16px 2px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 5px 6px -3px rgba(0, 0, 0, 0.2), 0px 9px 12px 1px rgba(0, 0, 0, 0.14), 0px 3px 16px 2px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z10 {\n     -webkit-box-shadow: 0px 6px 6px -3px rgba(0, 0, 0, 0.2), 0px 10px 14px 1px rgba(0, 0, 0, 0.14), 0px 4px 18px 3px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 6px 6px -3px rgba(0, 0, 0, 0.2), 0px 10px 14px 1px rgba(0, 0, 0, 0.14), 0px 4px 18px 3px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z11 {\n     -webkit-box-shadow: 0px 6px 7px -4px rgba(0, 0, 0, 0.2), 0px 11px 15px 1px rgba(0, 0, 0, 0.14), 0px 4px 20px 3px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 6px 7px -4px rgba(0, 0, 0, 0.2), 0px 11px 15px 1px rgba(0, 0, 0, 0.14), 0px 4px 20px 3px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z12 {\n     -webkit-box-shadow: 0px 7px 8px -4px rgba(0, 0, 0, 0.2), 0px 12px 17px 2px rgba(0, 0, 0, 0.14), 0px 5px 22px 4px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 7px 8px -4px rgba(0, 0, 0, 0.2), 0px 12px 17px 2px rgba(0, 0, 0, 0.14), 0px 5px 22px 4px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z13 {\n     -webkit-box-shadow: 0px 7px 8px -4px rgba(0, 0, 0, 0.2), 0px 13px 19px 2px rgba(0, 0, 0, 0.14), 0px 5px 24px 4px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 7px 8px -4px rgba(0, 0, 0, 0.2), 0px 13px 19px 2px rgba(0, 0, 0, 0.14), 0px 5px 24px 4px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z14 {\n     -webkit-box-shadow: 0px 7px 9px -4px rgba(0, 0, 0, 0.2), 0px 14px 21px 2px rgba(0, 0, 0, 0.14), 0px 5px 26px 4px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 7px 9px -4px rgba(0, 0, 0, 0.2), 0px 14px 21px 2px rgba(0, 0, 0, 0.14), 0px 5px 26px 4px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z15 {\n     -webkit-box-shadow: 0px 8px 9px -5px rgba(0, 0, 0, 0.2), 0px 15px 22px 2px rgba(0, 0, 0, 0.14), 0px 6px 28px 5px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 8px 9px -5px rgba(0, 0, 0, 0.2), 0px 15px 22px 2px rgba(0, 0, 0, 0.14), 0px 6px 28px 5px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z16 {\n     -webkit-box-shadow: 0px 8px 10px -5px rgba(0, 0, 0, 0.2), 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 8px 10px -5px rgba(0, 0, 0, 0.2), 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z17 {\n     -webkit-box-shadow: 0px 8px 11px -5px rgba(0, 0, 0, 0.2), 0px 17px 26px 2px rgba(0, 0, 0, 0.14), 0px 6px 32px 5px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 8px 11px -5px rgba(0, 0, 0, 0.2), 0px 17px 26px 2px rgba(0, 0, 0, 0.14), 0px 6px 32px 5px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z18 {\n     -webkit-box-shadow: 0px 9px 11px -5px rgba(0, 0, 0, 0.2), 0px 18px 28px 2px rgba(0, 0, 0, 0.14), 0px 7px 34px 6px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 9px 11px -5px rgba(0, 0, 0, 0.2), 0px 18px 28px 2px rgba(0, 0, 0, 0.14), 0px 7px 34px 6px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z19 {\n     -webkit-box-shadow: 0px 9px 12px -6px rgba(0, 0, 0, 0.2), 0px 19px 29px 2px rgba(0, 0, 0, 0.14), 0px 7px 36px 6px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 9px 12px -6px rgba(0, 0, 0, 0.2), 0px 19px 29px 2px rgba(0, 0, 0, 0.14), 0px 7px 36px 6px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z20 {\n     -webkit-box-shadow: 0px 10px 13px -6px rgba(0, 0, 0, 0.2), 0px 20px 31px 3px rgba(0, 0, 0, 0.14), 0px 8px 38px 7px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 10px 13px -6px rgba(0, 0, 0, 0.2), 0px 20px 31px 3px rgba(0, 0, 0, 0.14), 0px 8px 38px 7px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z21 {\n     -webkit-box-shadow: 0px 10px 13px -6px rgba(0, 0, 0, 0.2), 0px 21px 33px 3px rgba(0, 0, 0, 0.14), 0px 8px 40px 7px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 10px 13px -6px rgba(0, 0, 0, 0.2), 0px 21px 33px 3px rgba(0, 0, 0, 0.14), 0px 8px 40px 7px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z22 {\n     -webkit-box-shadow: 0px 10px 14px -6px rgba(0, 0, 0, 0.2), 0px 22px 35px 3px rgba(0, 0, 0, 0.14), 0px 8px 42px 7px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 10px 14px -6px rgba(0, 0, 0, 0.2), 0px 22px 35px 3px rgba(0, 0, 0, 0.14), 0px 8px 42px 7px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z23 {\n     -webkit-box-shadow: 0px 11px 14px -7px rgba(0, 0, 0, 0.2), 0px 23px 36px 3px rgba(0, 0, 0, 0.14), 0px 9px 44px 8px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 11px 14px -7px rgba(0, 0, 0, 0.2), 0px 23px 36px 3px rgba(0, 0, 0, 0.14), 0px 9px 44px 8px rgba(0, 0, 0, 0.12); }\n\n   .mat-elevation-z24 {\n     -webkit-box-shadow: 0px 11px 15px -7px rgba(0, 0, 0, 0.2), 0px 24px 38px 3px rgba(0, 0, 0, 0.14), 0px 9px 46px 8px rgba(0, 0, 0, 0.12);\n             box-shadow: 0px 11px 15px -7px rgba(0, 0, 0, 0.2), 0px 24px 38px 3px rgba(0, 0, 0, 0.14), 0px 9px 46px 8px rgba(0, 0, 0, 0.12); }\n\n   .mat-ripple {\n     overflow: hidden; }\n\n   .mat-ripple.mat-ripple-unbounded {\n     overflow: visible; }\n\n   .mat-ripple-element {\n     position: absolute;\n     border-radius: 50%;\n     pointer-events: none;\n     -webkit-transition: opacity, -webkit-transform 0ms cubic-bezier(0, 0, 0.2, 1);\n     transition: opacity, -webkit-transform 0ms cubic-bezier(0, 0, 0.2, 1);\n     transition: opacity, transform 0ms cubic-bezier(0, 0, 0.2, 1);\n     transition: opacity, transform 0ms cubic-bezier(0, 0, 0.2, 1), -webkit-transform 0ms cubic-bezier(0, 0, 0.2, 1);\n     -webkit-transform: scale(0);\n         -ms-transform: scale(0);\n             transform: scale(0); }\n\n   .mat-option {\n     white-space: nowrap;\n     overflow: hidden;\n     text-overflow: ellipsis;\n     display: block;\n     line-height: 48px;\n     height: 48px;\n     padding: 0 16px;\n     font-size: 16px;\n     font-family: Roboto, \"Helvetica Neue\", sans-serif;\n     text-align: left;\n     text-decoration: none;\n     position: relative;\n     cursor: pointer;\n     outline: none; }\n     .mat-option[disabled] {\n       cursor: default; }\n     [dir='rtl'] .mat-option {\n       text-align: right; }\n     .mat-option .mat-icon {\n       margin-right: 16px; }\n       [dir='rtl'] .mat-option .mat-icon {\n         margin-left: 16px; }\n     .mat-option[aria-disabled='true'] {\n       -webkit-user-select: none;\n       -moz-user-select: none;\n       -ms-user-select: none;\n       user-select: none;\n       cursor: default; }\n\n   .mat-option-ripple {\n     position: absolute;\n     top: 0;\n     left: 0;\n     bottom: 0;\n     right: 0; }\n     @media screen and (-ms-high-contrast: active) {\n       .mat-option-ripple {\n         opacity: 0.5; } }\n\n   .mat-option-pseudo-checkbox {\n     margin-right: 8px; }\n     [dir='rtl'] .mat-option-pseudo-checkbox {\n       margin-left: 8px;\n       margin-right: 0; }\n\n   .cdk-visually-hidden {\n     border: 0;\n     clip: rect(0 0 0 0);\n     height: 1px;\n     margin: -1px;\n     overflow: hidden;\n     padding: 0;\n     position: absolute;\n     text-transform: none;\n     width: 1px; }\n\n   .cdk-overlay-container, .cdk-global-overlay-wrapper {\n     pointer-events: none;\n     top: 0;\n     left: 0;\n     height: 100%;\n     width: 100%; }\n\n   .cdk-overlay-container {\n     position: fixed;\n     z-index: 1000; }\n\n   .cdk-global-overlay-wrapper {\n     display: -webkit-box;\n     display: -webkit-flex;\n     display: -ms-flexbox;\n     display: flex;\n     position: absolute;\n     z-index: 1000; }\n\n   .cdk-overlay-pane {\n     position: absolute;\n     pointer-events: auto;\n     -webkit-box-sizing: border-box;\n             box-sizing: border-box;\n     z-index: 1000; }\n\n   .cdk-overlay-backdrop {\n     position: absolute;\n     top: 0;\n     bottom: 0;\n     left: 0;\n     right: 0;\n     z-index: 1000;\n     pointer-events: auto;\n     -webkit-transition: opacity 400ms cubic-bezier(0.25, 0.8, 0.25, 1);\n     transition: opacity 400ms cubic-bezier(0.25, 0.8, 0.25, 1);\n     opacity: 0; }\n     .cdk-overlay-backdrop.cdk-overlay-backdrop-showing {\n       opacity: 0.48; }\n\n   .cdk-overlay-dark-backdrop {\n     background: rgba(0, 0, 0, 0.6); }\n\n   .cdk-overlay-transparent-backdrop {\n     background: none; }\n\n   .mat-ripple-element {\n     background-color: rgba(0, 0, 0, 0.1); }\n\n   .mat-option:hover:not(.mat-option-disabled), .mat-option:focus:not(.mat-option-disabled) {\n     background: rgba(0, 0, 0, 0.04); }\n\n   .mat-option.mat-selected {\n     color: #009688; }\n     .mat-option.mat-selected:not(.mat-option-multiple) {\n       background: rgba(0, 0, 0, 0.04); }\n\n   .mat-option.mat-active {\n     background: rgba(0, 0, 0, 0.04);\n     color: rgba(0, 0, 0, 0.87); }\n\n   .mat-option.mat-option-disabled {\n     color: rgba(0, 0, 0, 0.38); }\n\n   .mat-pseudo-checkbox {\n     color: rgba(0, 0, 0, 0.54); }\n     .mat-pseudo-checkbox::after {\n       color: #fafafa; }\n\n   .mat-pseudo-checkbox-checked.mat-primary, .mat-pseudo-checkbox-indeterminate.mat-primary {\n     background: #009688; }\n\n   .mat-pseudo-checkbox-checked.mat-accent, .mat-pseudo-checkbox-indeterminate.mat-accent {\n     background: #009688; }\n\n   .mat-pseudo-checkbox-checked.mat-warn, .mat-pseudo-checkbox-indeterminate.mat-warn {\n     background: #f44336; }\n\n   .mat-pseudo-checkbox-checked.mat-pseudo-checkbox-disabled, .mat-pseudo-checkbox-indeterminate.mat-pseudo-checkbox-disabled {\n     background: #b0b0b0; }\n\n   .mat-app-background {\n     background-color: #fafafa; }\n\n   .mat-theme-loaded-marker {\n     display: none; }\n\n   .mat-autocomplete-panel {\n     background: white;\n     color: rgba(0, 0, 0, 0.87); }\n     .mat-autocomplete-panel .mat-option.mat-selected:not(.mat-active) {\n       background: white;\n       color: rgba(0, 0, 0, 0.87); }\n\n   .mat-button.mat-primary .mat-button-focus-overlay, .mat-icon-button.mat-primary .mat-button-focus-overlay, .mat-raised-button.mat-primary .mat-button-focus-overlay, .mat-fab.mat-primary .mat-button-focus-overlay, .mat-mini-fab.mat-primary .mat-button-focus-overlay {\n     background-color: rgba(0, 150, 136, 0.12); }\n\n   .mat-button.mat-accent .mat-button-focus-overlay, .mat-icon-button.mat-accent .mat-button-focus-overlay, .mat-raised-button.mat-accent .mat-button-focus-overlay, .mat-fab.mat-accent .mat-button-focus-overlay, .mat-mini-fab.mat-accent .mat-button-focus-overlay {\n     background-color: rgba(0, 150, 136, 0.12); }\n\n   .mat-button.mat-warn .mat-button-focus-overlay, .mat-icon-button.mat-warn .mat-button-focus-overlay, .mat-raised-button.mat-warn .mat-button-focus-overlay, .mat-fab.mat-warn .mat-button-focus-overlay, .mat-mini-fab.mat-warn .mat-button-focus-overlay {\n     background-color: rgba(244, 67, 54, 0.12); }\n\n   .mat-button[disabled] .mat-button-focus-overlay, .mat-icon-button[disabled] .mat-button-focus-overlay, .mat-raised-button[disabled] .mat-button-focus-overlay, .mat-fab[disabled] .mat-button-focus-overlay, .mat-mini-fab[disabled] .mat-button-focus-overlay {\n     background-color: transparent; }\n\n   .mat-button, .mat-icon-button {\n     background: transparent; }\n     .mat-button.mat-primary, .mat-icon-button.mat-primary {\n       color: #009688; }\n     .mat-button.mat-accent, .mat-icon-button.mat-accent {\n       color: #009688; }\n     .mat-button.mat-warn, .mat-icon-button.mat-warn {\n       color: #f44336; }\n     .mat-button.mat-primary[disabled], .mat-button.mat-accent[disabled], .mat-button.mat-warn[disabled], .mat-button[disabled][disabled], .mat-icon-button.mat-primary[disabled], .mat-icon-button.mat-accent[disabled], .mat-icon-button.mat-warn[disabled], .mat-icon-button[disabled][disabled] {\n       color: rgba(0, 0, 0, 0.38); }\n\n   .mat-icon-button.mat-primary .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.26); }\n\n   .mat-icon-button.mat-accent .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.26); }\n\n   .mat-icon-button.mat-warn .mat-ripple-element {\n     background-color: rgba(244, 67, 54, 0.26); }\n\n   .mat-raised-button, .mat-fab, .mat-mini-fab {\n     color: rgba(0, 0, 0, 0.87);\n     background-color: white; }\n     .mat-raised-button.mat-primary, .mat-fab.mat-primary, .mat-mini-fab.mat-primary {\n       color: white; }\n     .mat-raised-button.mat-accent, .mat-fab.mat-accent, .mat-mini-fab.mat-accent {\n       color: white; }\n     .mat-raised-button.mat-warn, .mat-fab.mat-warn, .mat-mini-fab.mat-warn {\n       color: white; }\n     .mat-raised-button.mat-primary[disabled], .mat-raised-button.mat-accent[disabled], .mat-raised-button.mat-warn[disabled], .mat-raised-button[disabled][disabled], .mat-fab.mat-primary[disabled], .mat-fab.mat-accent[disabled], .mat-fab.mat-warn[disabled], .mat-fab[disabled][disabled], .mat-mini-fab.mat-primary[disabled], .mat-mini-fab.mat-accent[disabled], .mat-mini-fab.mat-warn[disabled], .mat-mini-fab[disabled][disabled] {\n       color: rgba(0, 0, 0, 0.38); }\n     .mat-raised-button.mat-primary, .mat-fab.mat-primary, .mat-mini-fab.mat-primary {\n       background-color: #009688; }\n     .mat-raised-button.mat-accent, .mat-fab.mat-accent, .mat-mini-fab.mat-accent {\n       background-color: #009688; }\n     .mat-raised-button.mat-warn, .mat-fab.mat-warn, .mat-mini-fab.mat-warn {\n       background-color: #f44336; }\n     .mat-raised-button.mat-primary[disabled], .mat-raised-button.mat-accent[disabled], .mat-raised-button.mat-warn[disabled], .mat-raised-button[disabled][disabled], .mat-fab.mat-primary[disabled], .mat-fab.mat-accent[disabled], .mat-fab.mat-warn[disabled], .mat-fab[disabled][disabled], .mat-mini-fab.mat-primary[disabled], .mat-mini-fab.mat-accent[disabled], .mat-mini-fab.mat-warn[disabled], .mat-mini-fab[disabled][disabled] {\n       background-color: rgba(0, 0, 0, 0.12); }\n\n   .mat-fab, .mat-mini-fab {\n     background-color: #009688;\n     color: white; }\n\n   .mat-button-toggle {\n     color: rgba(0, 0, 0, 0.38); }\n     .mat-button-toggle.cdk-focused .mat-button-toggle-focus-overlay {\n       background-color: rgba(0, 0, 0, 0.06); }\n\n   .mat-button-toggle-checked {\n     background-color: #e0e0e0;\n     color: black; }\n\n   .mat-button-toggle-disabled {\n     background-color: #eeeeee;\n     color: rgba(0, 0, 0, 0.38); }\n     .mat-button-toggle-disabled.mat-button-toggle-checked {\n       background-color: #bdbdbd; }\n\n   .mat-card {\n     background: white;\n     color: black; }\n\n   .mat-card-subtitle {\n     color: rgba(0, 0, 0, 0.54); }\n\n   .mat-checkbox-frame {\n     border-color: rgba(0, 0, 0, 0.54); }\n\n   .mat-checkbox-checkmark {\n     fill: #fafafa; }\n\n   .mat-checkbox-checkmark-path {\n     stroke: #fafafa !important; }\n\n   .mat-checkbox-mixedmark {\n     background-color: #fafafa; }\n\n   .mat-checkbox-indeterminate.mat-primary .mat-checkbox-background, .mat-checkbox-checked.mat-primary .mat-checkbox-background {\n     background-color: #009688; }\n\n   .mat-checkbox-indeterminate.mat-accent .mat-checkbox-background, .mat-checkbox-checked.mat-accent .mat-checkbox-background {\n     background-color: #009688; }\n\n   .mat-checkbox-indeterminate.mat-warn .mat-checkbox-background, .mat-checkbox-checked.mat-warn .mat-checkbox-background {\n     background-color: #f44336; }\n\n   .mat-checkbox-disabled.mat-checkbox-checked .mat-checkbox-background, .mat-checkbox-disabled.mat-checkbox-indeterminate .mat-checkbox-background {\n     background-color: #b0b0b0; }\n\n   .mat-checkbox-disabled:not(.mat-checkbox-checked) .mat-checkbox-frame {\n     border-color: #b0b0b0; }\n\n   .mat-checkbox:not(.mat-checkbox-disabled).mat-primary .mat-checkbox-ripple .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.26); }\n\n   .mat-checkbox:not(.mat-checkbox-disabled).mat-accent .mat-checkbox-ripple .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.26); }\n\n   .mat-checkbox:not(.mat-checkbox-disabled).mat-warn .mat-checkbox-ripple .mat-ripple-element {\n     background-color: rgba(244, 67, 54, 0.26); }\n\n   .mat-chip:not(.mat-basic-chip) {\n     background-color: #e0e0e0;\n     color: rgba(0, 0, 0, 0.87); }\n\n   .mat-chip.mat-chip-selected:not(.mat-basic-chip) {\n     background-color: #808080;\n     color: rgba(255, 255, 255, 0.87); }\n     .mat-chip.mat-chip-selected:not(.mat-basic-chip).mat-primary {\n       background-color: #009688;\n       color: white; }\n     .mat-chip.mat-chip-selected:not(.mat-basic-chip).mat-accent {\n       background-color: #009688;\n       color: white; }\n     .mat-chip.mat-chip-selected:not(.mat-basic-chip).mat-warn {\n       background-color: #f44336;\n       color: white; }\n\n   .mat-dialog-container {\n     background: white; }\n\n   .mat-icon.mat-primary {\n     color: #009688; }\n\n   .mat-icon.mat-accent {\n     color: #009688; }\n\n   .mat-icon.mat-warn {\n     color: #f44336; }\n\n   .mat-input-placeholder {\n     color: rgba(0, 0, 0, 0.38); }\n     .mat-focused .mat-input-placeholder {\n       color: #009688; }\n       .mat-focused .mat-input-placeholder.mat-accent {\n         color: #009688; }\n       .mat-focused .mat-input-placeholder.mat-warn {\n         color: #f44336; }\n\n   .mat-input-element:disabled {\n     color: rgba(0, 0, 0, 0.38); }\n\n   input.mat-input-element:-webkit-autofill + .mat-input-placeholder .mat-placeholder-required,\n   .mat-focused .mat-input-placeholder.mat-float .mat-placeholder-required {\n     color: #009688; }\n\n   .mat-input-underline {\n     border-color: rgba(0, 0, 0, 0.12); }\n     .mat-input-underline .mat-input-ripple {\n       background-color: #009688; }\n       .mat-input-underline .mat-input-ripple.mat-accent {\n         background-color: #009688; }\n       .mat-input-underline .mat-input-ripple.mat-warn {\n         background-color: #f44336; }\n\n   .mat-input-invalid .mat-input-placeholder,\n   .mat-input-invalid .mat-placeholder-required {\n     color: #f44336; }\n\n   .mat-input-invalid .mat-input-underline {\n     border-color: #f44336; }\n\n   .mat-input-invalid .mat-input-ripple {\n     background-color: #f44336; }\n\n   .mat-input-error {\n     color: #f44336; }\n\n   .mat-list .mat-list-item, .mat-nav-list .mat-list-item {\n     color: black; }\n\n   .mat-list .mat-subheader, .mat-nav-list .mat-subheader {\n     color: rgba(0, 0, 0, 0.54); }\n\n   .mat-divider {\n     border-top-color: rgba(0, 0, 0, 0.12); }\n\n   .mat-nav-list .mat-list-item-content:hover, .mat-nav-list .mat-list-item-content.mat-list-item-focus {\n     background: rgba(0, 0, 0, 0.04); }\n\n   .mat-menu-content {\n     background: white; }\n\n   .mat-menu-item {\n     background: transparent;\n     color: rgba(0, 0, 0, 0.87); }\n     .mat-menu-item[disabled] {\n       color: rgba(0, 0, 0, 0.38); }\n     .mat-menu-item .mat-icon {\n       color: rgba(0, 0, 0, 0.54);\n       vertical-align: middle; }\n     .mat-menu-item:hover:not([disabled]), .mat-menu-item:focus:not([disabled]) {\n       background: rgba(0, 0, 0, 0.04); }\n\n   .mat-progress-bar-background {\n     background: url(\"data:image/svg+xml;charset=UTF-8,%3Csvg%20version%3D%271.1%27%20xmlns%3D%27http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%27%20xmlns%3Axlink%3D%27http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%27%20x%3D%270px%27%20y%3D%270px%27%20enable-background%3D%27new%200%200%205%202%27%20xml%3Aspace%3D%27preserve%27%20viewBox%3D%270%200%205%202%27%20preserveAspectRatio%3D%27none%20slice%27%3E%3Ccircle%20cx%3D%271%27%20cy%3D%271%27%20r%3D%271%27%20fill%3D%27%23b3e0db%27%2F%3E%3C%2Fsvg%3E\"); }\n\n   .mat-progress-bar-buffer {\n     background-color: #b3e0db; }\n\n   .mat-progress-bar-fill::after {\n     background-color: #008e80; }\n\n   .mat-progress-bar.mat-accent .mat-progress-bar-background {\n     background: url(\"data:image/svg+xml;charset=UTF-8,%3Csvg%20version%3D%271.1%27%20xmlns%3D%27http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%27%20xmlns%3Axlink%3D%27http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%27%20x%3D%270px%27%20y%3D%270px%27%20enable-background%3D%27new%200%200%205%202%27%20xml%3Aspace%3D%27preserve%27%20viewBox%3D%270%200%205%202%27%20preserveAspectRatio%3D%27none%20slice%27%3E%3Ccircle%20cx%3D%271%27%20cy%3D%271%27%20r%3D%271%27%20fill%3D%27%23b3e0db%27%2F%3E%3C%2Fsvg%3E\"); }\n\n   .mat-progress-bar.mat-accent .mat-progress-bar-buffer {\n     background-color: #b3e0db; }\n\n   .mat-progress-bar.mat-accent .mat-progress-bar-fill::after {\n     background-color: #008e80; }\n\n   .mat-progress-bar.mat-warn .mat-progress-bar-background {\n     background: url(\"data:image/svg+xml;charset=UTF-8,%3Csvg%20version%3D%271.1%27%20xmlns%3D%27http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%27%20xmlns%3Axlink%3D%27http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%27%20x%3D%270px%27%20y%3D%270px%27%20enable-background%3D%27new%200%200%205%202%27%20xml%3Aspace%3D%27preserve%27%20viewBox%3D%270%200%205%202%27%20preserveAspectRatio%3D%27none%20slice%27%3E%3Ccircle%20cx%3D%271%27%20cy%3D%271%27%20r%3D%271%27%20fill%3D%27%23ffcdd2%27%2F%3E%3C%2Fsvg%3E\"); }\n\n   .mat-progress-bar.mat-warn .mat-progress-bar-buffer {\n     background-color: #ffcdd2; }\n\n   .mat-progress-bar.mat-warn .mat-progress-bar-fill::after {\n     background-color: #e53935; }\n\n   .mat-progress-spinner path, .mat-spinner path {\n     stroke: #008e80; }\n\n   .mat-progress-spinner.mat-accent path, .mat-spinner.mat-accent path {\n     stroke: #008e80; }\n\n   .mat-progress-spinner.mat-warn path, .mat-spinner.mat-warn path {\n     stroke: #e53935; }\n\n   .mat-radio-outer-circle {\n     border-color: rgba(0, 0, 0, 0.54); }\n     .mat-radio-checked .mat-radio-outer-circle {\n       border-color: #009688; }\n     .mat-radio-disabled .mat-radio-outer-circle {\n       border-color: rgba(0, 0, 0, 0.38); }\n\n   .mat-radio-inner-circle {\n     background-color: #009688; }\n     .mat-radio-disabled .mat-radio-inner-circle {\n       background-color: rgba(0, 0, 0, 0.38); }\n\n   .mat-radio-ripple .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.26); }\n     .mat-radio-disabled .mat-radio-ripple .mat-ripple-element {\n       background-color: rgba(0, 0, 0, 0.38); }\n\n   .mat-select-trigger {\n     color: rgba(0, 0, 0, 0.38); }\n     .mat-select:focus:not(.mat-select-disabled) .mat-select-trigger {\n       color: #009688; }\n     .mat-select:not(:focus).ng-invalid.ng-touched:not(.mat-select-disabled) .mat-select-trigger {\n       color: #f44336; }\n\n   .mat-select-underline {\n     background-color: rgba(0, 0, 0, 0.12); }\n     .mat-select:focus:not(.mat-select-disabled) .mat-select-underline {\n       background-color: #009688; }\n     .mat-select:not(:focus).ng-invalid.ng-touched:not(.mat-select-disabled) .mat-select-underline {\n       background-color: #f44336; }\n\n   .mat-select-arrow {\n     color: rgba(0, 0, 0, 0.38); }\n     .mat-select:focus:not(.mat-select-disabled) .mat-select-arrow {\n       color: #009688; }\n     .mat-select:not(:focus).ng-invalid.ng-touched:not(.mat-select-disabled) .mat-select-arrow {\n       color: #f44336; }\n\n   .mat-select-content, .mat-select-panel-done-animating {\n     background: white; }\n\n   .mat-select-value {\n     color: rgba(0, 0, 0, 0.87); }\n     .mat-select-disabled .mat-select-value {\n       color: rgba(0, 0, 0, 0.38); }\n\n   .mat-sidenav-container {\n     background-color: #fafafa;\n     color: rgba(0, 0, 0, 0.87); }\n\n   .mat-sidenav {\n     background-color: white;\n     color: rgba(0, 0, 0, 0.87); }\n     .mat-sidenav.mat-sidenav-push {\n       background-color: white; }\n\n   .mat-sidenav-backdrop.mat-sidenav-shown {\n     background-color: rgba(0, 0, 0, 0.6); }\n\n   .mat-slide-toggle.mat-checked:not(.mat-disabled) .mat-slide-toggle-thumb {\n     background-color: #009688; }\n\n   .mat-slide-toggle.mat-checked:not(.mat-disabled) .mat-slide-toggle-bar {\n     background-color: rgba(0, 150, 136, 0.5); }\n\n   .mat-slide-toggle:not(.mat-checked) .mat-ripple-element {\n     background-color: rgba(0, 0, 0, 0.06); }\n\n   .mat-slide-toggle .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.12); }\n\n   .mat-slide-toggle.mat-primary.mat-checked:not(.mat-disabled) .mat-slide-toggle-thumb {\n     background-color: #009688; }\n\n   .mat-slide-toggle.mat-primary.mat-checked:not(.mat-disabled) .mat-slide-toggle-bar {\n     background-color: rgba(0, 150, 136, 0.5); }\n\n   .mat-slide-toggle.mat-primary:not(.mat-checked) .mat-ripple-element {\n     background-color: rgba(0, 0, 0, 0.06); }\n\n   .mat-slide-toggle.mat-primary .mat-ripple-element {\n     background-color: rgba(0, 150, 136, 0.12); }\n\n   .mat-slide-toggle.mat-warn.mat-checked:not(.mat-disabled) .mat-slide-toggle-thumb {\n     background-color: #f44336; }\n\n   .mat-slide-toggle.mat-warn.mat-checked:not(.mat-disabled) .mat-slide-toggle-bar {\n     background-color: rgba(244, 67, 54, 0.5); }\n\n   .mat-slide-toggle.mat-warn:not(.mat-checked) .mat-ripple-element {\n     background-color: rgba(0, 0, 0, 0.06); }\n\n   .mat-slide-toggle.mat-warn .mat-ripple-element {\n     background-color: rgba(244, 67, 54, 0.12); }\n\n   .mat-disabled .mat-slide-toggle-thumb {\n     background-color: #bdbdbd; }\n\n   .mat-disabled .mat-slide-toggle-bar {\n     background-color: rgba(0, 0, 0, 0.1); }\n\n   .mat-slide-toggle-thumb {\n     background-color: #fafafa; }\n\n   .mat-slide-toggle-bar {\n     background-color: rgba(0, 0, 0, 0.38); }\n\n   .mat-slider-track-background {\n     background-color: rgba(0, 0, 0, 0.26); }\n\n   .mat-primary .mat-slider-track-fill, .mat-primary\n   .mat-slider-thumb, .mat-primary\n   .mat-slider-thumb-label {\n     background-color: #009688; }\n\n   .mat-accent .mat-slider-track-fill, .mat-accent\n   .mat-slider-thumb, .mat-accent\n   .mat-slider-thumb-label {\n     background-color: #009688; }\n\n   .mat-warn .mat-slider-track-fill, .mat-warn\n   .mat-slider-thumb, .mat-warn\n   .mat-slider-thumb-label {\n     background-color: #f44336; }\n\n   .mat-slider-focus-ring {\n     background-color: rgba(0, 150, 136, 0.2); }\n\n   .mat-primary .mat-slider-thumb-label-text {\n     color: white; }\n\n   .mat-accent .mat-slider-thumb-label-text {\n     color: white; }\n\n   .mat-warn .mat-slider-thumb-label-text {\n     color: white; }\n\n   .mat-slider:hover .mat-slider-track-background,\n   .cdk-focused .mat-slider-track-background {\n     background-color: rgba(0, 0, 0, 0.38); }\n\n   .mat-slider-disabled .mat-slider-track-background,\n   .mat-slider-disabled .mat-slider-track-fill,\n   .mat-slider-disabled .mat-slider-thumb {\n     background-color: rgba(0, 0, 0, 0.26); }\n\n   .mat-slider-disabled:hover .mat-slider-track-background {\n     background-color: rgba(0, 0, 0, 0.26); }\n\n   .mat-slider-min-value .mat-slider-focus-ring {\n     background-color: rgba(0, 0, 0, 0.12); }\n\n   .mat-slider-min-value.mat-slider-thumb-label-showing .mat-slider-thumb,\n   .mat-slider-min-value.mat-slider-thumb-label-showing .mat-slider-thumb-label {\n     background-color: black; }\n\n   .mat-slider-min-value.mat-slider-thumb-label-showing.cdk-focused .mat-slider-thumb,\n   .mat-slider-min-value.mat-slider-thumb-label-showing.cdk-focused .mat-slider-thumb-label {\n     background-color: rgba(0, 0, 0, 0.26); }\n\n   .mat-slider-min-value:not(.mat-slider-thumb-label-showing) .mat-slider-thumb {\n     border-color: rgba(0, 0, 0, 0.26);\n     background-color: transparent; }\n\n   .mat-slider-min-value:not(.mat-slider-thumb-label-showing):hover .mat-slider-thumb, .mat-slider-min-value:not(.mat-slider-thumb-label-showing).cdk-focused .mat-slider-thumb {\n     border-color: rgba(0, 0, 0, 0.38); }\n\n   .mat-slider-min-value:not(.mat-slider-thumb-label-showing):hover.mat-slider-disabled .mat-slider-thumb, .mat-slider-min-value:not(.mat-slider-thumb-label-showing).cdk-focused.mat-slider-disabled .mat-slider-thumb {\n     border-color: rgba(0, 0, 0, 0.26); }\n\n   .mat-tab-nav-bar,\n   .mat-tab-header {\n     border-bottom: 1px solid #e0e0e0; }\n     .mat-tab-group-inverted-header .mat-tab-nav-bar, .mat-tab-group-inverted-header\n     .mat-tab-header {\n       border-top: 1px solid #e0e0e0;\n       border-bottom: none; }\n\n   .mat-tab-label:focus {\n     background-color: rgba(179, 224, 219, 0.3); }\n\n   .mat-ink-bar {\n     background-color: #009688; }\n\n   .mat-tab-label, .mat-tab-link {\n     color: currentColor; }\n     .mat-tab-label.mat-tab-disabled, .mat-tab-link.mat-tab-disabled {\n       color: rgba(0, 0, 0, 0.38); }\n\n   .mat-toolbar {\n     background: whitesmoke;\n     color: rgba(0, 0, 0, 0.87); }\n     .mat-toolbar.mat-primary {\n       background: #009688;\n       color: white; }\n     .mat-toolbar.mat-accent {\n       background: #009688;\n       color: white; }\n     .mat-toolbar.mat-warn {\n       background: #f44336;\n       color: white; }\n\n   .mat-tooltip {\n     background: rgba(97, 97, 97, 0.9); }\n\n   .openvidu-hangouts {\n     width: 100%;\n     height: 100%; }\n     .openvidu-hangouts .message-screen {\n       height: 100%;\n       background: #000;\n       color: #fff;\n       font-weight: bold;\n       font-size: 22px;\n       display: -webkit-box;\n       display: -webkit-flex;\n       display: -ms-flexbox;\n       display: flex;\n       -webkit-box-align: center;\n       -webkit-align-items: center;\n           -ms-flex-align: center;\n               align-items: center;\n       -webkit-box-pack: center;\n       -webkit-justify-content: center;\n           -ms-flex-pack: center;\n               justify-content: center; }\n     .openvidu-hangouts .wrapper {\n       display: -webkit-box;\n       display: -webkit-flex;\n       display: -ms-flexbox;\n       display: flex;\n       -webkit-box-orient: vertical;\n       -webkit-box-direction: normal;\n       -webkit-flex-direction: column;\n           -ms-flex-direction: column;\n               flex-direction: column;\n       position: relative;\n       height: 100%; }\n       .openvidu-hangouts .wrapper .toolbar .example-icon {\n         padding: 0 14px; }\n       .openvidu-hangouts .wrapper .toolbar .example-spacer {\n         -webkit-box-flex: 1;\n         -webkit-flex: 1 1 auto;\n             -ms-flex: 1 1 auto;\n                 flex: 1 1 auto; }\n       .openvidu-hangouts .wrapper md-sidenav-container {\n         -webkit-box-flex: 1;\n         -webkit-flex: 1;\n             -ms-flex: 1;\n                 flex: 1;\n         height: 400px; }\n         .openvidu-hangouts .wrapper md-sidenav-container md-sidenav {\n           display: -webkit-box;\n           display: -webkit-flex;\n           display: -ms-flexbox;\n           display: flex;\n           -webkit-box-orient: vertical;\n           -webkit-box-direction: normal;\n           -webkit-flex-direction: column;\n               -ms-flex-direction: column;\n                   flex-direction: column;\n           background: #212121;\n           color: #fff;\n           width: 25vw;\n           min-width: 300px; }\n           .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .transparent-button {\n             background: none;\n             -webkit-box-shadow: none;\n                     box-shadow: none; }\n           .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .messages {\n             -webkit-box-flex: 1px;\n             -webkit-flex: 1px;\n                 -ms-flex: 1px;\n                     flex: 1px;\n             overflow: auto; }\n             .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .messages ul {\n               list-style: none;\n               margin: 20px 0px;\n               padding: 0px 30px; }\n               .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .messages ul li {\n                 display: -webkit-box;\n                 display: -webkit-flex;\n                 display: -ms-flexbox;\n                 display: flex;\n                 -webkit-box-orient: horizontal;\n                 -webkit-box-direction: normal;\n                 -webkit-flex-direction: row;\n                     -ms-flex-direction: row;\n                         flex-direction: row;\n                 font-size: 14px;\n                 margin: 7px 0 7px 0px; }\n                 .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .messages ul li div {\n                   -webkit-box-flex: 1;\n                   -webkit-flex: 1;\n                       -ms-flex: 1;\n                           flex: 1;\n                   margin-right: 10px;\n                   color: rgba(255, 255, 255, 0.7);\n                   word-break: break-word; }\n                   .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .messages ul li div span {\n                     color: #fff;\n                     margin-right: 6px; }\n                 .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .messages ul li .date {\n                   color: rgba(255, 255, 255, 0.3); }\n           .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom {\n             display: -webkit-box;\n             display: -webkit-flex;\n             display: -ms-flexbox;\n             display: flex;\n             -webkit-box-orient: horizontal;\n             -webkit-box-direction: normal;\n             -webkit-flex-direction: row;\n                 -ms-flex-direction: row;\n                     flex-direction: row;\n             border-top: 1px solid rgba(255, 255, 255, 0.12); }\n             .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom form {\n               -webkit-box-flex: 1;\n               -webkit-flex: 1;\n                   -ms-flex: 1;\n                       flex: 1;\n               display: -webkit-box;\n               display: -webkit-flex;\n               display: -ms-flexbox;\n               display: flex;\n               -webkit-box-orient: horizontal;\n               -webkit-box-direction: normal;\n               -webkit-flex-direction: row;\n                   -ms-flex-direction: row;\n                       flex-direction: row; }\n               .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom form md-input-container {\n                 -webkit-box-flex: 1;\n                 -webkit-flex: 1;\n                     -ms-flex: 1;\n                         flex: 1;\n                 width: auto; }\n                 .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom form md-input-container /deep/ .mat-input-placeholder {\n                   color: rgba(255, 255, 255, 0.54); }\n                 .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom form md-input-container /deep/ .mat-input-underline {\n                   border-color: rgba(255, 255, 255, 0.7); }\n               .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom form .send-message {\n                 color: #757575; }\n                 .openvidu-hangouts .wrapper md-sidenav-container md-sidenav .bottom form .send-message.enabled {\n                   color: #0f9d58; }\n         .openvidu-hangouts .wrapper md-sidenav-container .main-video {\n           position: relative;\n           min-height: 200px;\n           -webkit-box-flex: 1;\n           -webkit-flex: 1;\n               -ms-flex: 1;\n                   flex: 1;\n           height: 100%;\n           overflow: hidden;\n           background: #111; }\n           .openvidu-hangouts .wrapper md-sidenav-container .main-video .message {\n             color: #fff;\n             text-align: center;\n             position: absolute;\n             top: 20px;\n             left: 0px;\n             right: 0px;\n             text-shadow: #000 1px 1px 3px;\n             z-index: 99; }\n           .openvidu-hangouts .wrapper md-sidenav-container .main-video .name-placeholder {\n             width: 100%;\n             height: 100%;\n             text-align: center;\n             position: relative; }\n             .openvidu-hangouts .wrapper md-sidenav-container .main-video .name-placeholder div {\n               background: #70826a;\n               width: 160px;\n               height: 160px;\n               border-radius: 50%;\n               left: 50%;\n               top: 50%;\n               position: absolute;\n               margin: -80px 0px 0px -80px;\n               font-size: 100px;\n               color: #fff;\n               line-height: 160px; }\n         .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar {\n           bottom: 0;\n           height: auto;\n           left: 0;\n           position: absolute;\n           text-align: center;\n           right: 0; }\n           .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons {\n             margin-bottom: 0;\n             text-align: center;\n             white-space: nowrap;\n             position: relative; }\n             .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button {\n               color: #fff;\n               background-color: rgba(0, 0, 0, 0.4);\n               margin: 16px 8px 40px 8px; }\n               .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button:hover {\n                 background-color: rgba(0, 0, 0, 0.6); }\n               .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-mic.disabled, .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-camera.disabled {\n                 color: #000;\n                 background-color: white; }\n                 .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-mic.disabled md-icon, .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-camera.disabled md-icon {\n                   display: none; }\n                   .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-mic.disabled md-icon.disabled-icon, .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-camera.disabled md-icon.disabled-icon {\n                     display: inline-block; }\n               .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-mic md-icon, .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-camera md-icon {\n                 display: inline-block; }\n                 .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-mic md-icon.disabled-icon, .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.toggle-camera md-icon.disabled-icon {\n                   display: none; }\n               .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .buttons button.close-session {\n                 background-color: #db4437; }\n           .openvidu-hangouts .wrapper md-sidenav-container .bottom-bar .streams {\n             display: -webkit-box;\n             display: -webkit-flex;\n             display: -ms-flexbox;\n             display: flex;\n             -webkit-box-pack: start;\n             -webkit-justify-content: flex-start;\n                 -ms-flex-pack: start;\n                     justify-content: flex-start;\n             max-width: 100%;\n             text-align: start;\n             padding: 8px 24px 0 24px;\n             height: 132px;\n             white-space: nowrap;\n             -webkit-transition: bottom 250ms ease-out,height 250ms ease-out;\n             transition: bottom 250ms ease-out,height 250ms ease-out;\n             -webkit-box-sizing: border-box;\n             box-sizing: border-box;\n             direction: rtl;\n             overflow: auto;\n             overflow: -moz-scrollbars-none; }\n         .openvidu-hangouts .wrapper md-sidenav-container .toggle-chat {\n           position: absolute;\n           background: #212121;\n           border-radius: 0px;\n           width: 48px;\n           height: 48px;\n           bottom: 58px; }\n           .openvidu-hangouts .wrapper md-sidenav-container .toggle-chat md-icon {\n             font-size: 24px;\n             line-height: 18px; }\n\t"],
        animations: [
            animations_1.trigger('chatButtonAnimation', [
                animations_1.state('hide', animations_1.style({
                    left: '-60px'
                })),
                animations_1.state('show', animations_1.style({
                    left: '0px'
                })),
                animations_1.transition('* => hide', [
                    animations_1.animate('0.225s ease-in-out')
                ]),
                animations_1.transition('* => show', [
                    animations_1.animate('0.225s ease-in-out')
                ])
            ])
        ]
    }),
    __metadata("design:paramtypes", [core_1.Renderer2, angular_bigscreen_1.BigScreenService,
        openvidu_hangouts_intl_1.OpenViduHangoutsIntl, material_1.MdDialog])
], OpenViduHangoutsComponent);
exports.OpenViduHangoutsComponent = OpenViduHangoutsComponent;
