import { EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { Connection, Session, Stream } from 'openvidu-browser';
/**
 * Export interfaces of the events for the user of the module
 */
export interface RoomConnectedEvent {
    session?: Session;
}
export interface CameraAccessEvent {
    access: boolean;
    camera?: Stream;
    error?: any;
}
export interface ParticipantEvent {
    participant: Connection;
}
export interface StreamEvent {
    stream: Stream;
}
export interface MessageEvent {
    session: Session;
    participant: Connection;
    message: string;
}
export interface ErrorEvent {
    error: any;
}
export interface ParticipantData {
    username: string;
}
/**
 * AngularOpenVidu Directive to create your own template
 * - Exports an API called: openviduApi
 */
export declare class OpenViduDirective implements OnDestroy, OnChanges {
    wsUrl: string;
    sessionId: string;
    participantId: string;
    apiKey: string;
    token: string;
    onRoomConnected: EventEmitter<RoomConnectedEvent>;
    onErrorRoom: EventEmitter<ErrorEvent>;
    onLeaveRoom: EventEmitter<void>;
    onErrorMedia: EventEmitter<ErrorEvent>;
    onLostConnection: EventEmitter<void>;
    onNewMessage: EventEmitter<MessageEvent>;
    onParticipantJoined: EventEmitter<ParticipantEvent>;
    onParticipantLeft: EventEmitter<ParticipantEvent>;
    onRoomClosed: EventEmitter<void>;
    onParticipantEvicted: EventEmitter<ParticipantEvent>;
    onParticipantPublished: EventEmitter<ParticipantEvent>;
    onStreamAdded: EventEmitter<StreamEvent>;
    onStreamRemoved: EventEmitter<StreamEvent>;
    onUpdateMainSpeaker: EventEmitter<StreamEvent>;
    onCustomNotification: EventEmitter<any>;
    onServerConnected: EventEmitter<void>;
    onErrorServer: EventEmitter<ErrorEvent>;
    onCameraAccessChange: EventEmitter<CameraAccessEvent>;
    private openvidu;
    private session;
    private participants;
    private streams;
    private mainStream;
    private myCamera;
    private myCameraId;
    private connectedToServer;
    ngOnDestroy(): void;
    ngOnChanges(): void;
    micEnabled: boolean;
    camEnabled: boolean;
    sendMessage(text: string): void;
    sendCustomNotification(obj: any, callback: any): void;
    /**
     * Set new camera device for current user.
     * @param deviceId - if null the camera is the default one
     */
    setCamera(deviceId: string): void;
    leaveRoom(): void;
    private joinRoom(setCamera?);
    private setListeners();
    /**
     * Update main speaker based on a established consensus
     */
    private autoUpdateMainSpeaker();
    /**
     * Update main speaker and emit event
     */
    private updateMainSpeakerManually(stream);
    /**
     * Get current token to connect to OpenVidu server
     */
    private getCurrentToken();
}
