"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var openvidu_browser_1 = require("openvidu-browser");
/**
 * AngularOpenVidu Directive to create your own template
 * - Exports an API called: openviduApi
 */
var OpenViduDirective = (function () {
    function OpenViduDirective() {
        // Outputs
        this.onRoomConnected = new core_1.EventEmitter();
        this.onErrorRoom = new core_1.EventEmitter();
        this.onLeaveRoom = new core_1.EventEmitter();
        this.onErrorMedia = new core_1.EventEmitter();
        this.onLostConnection = new core_1.EventEmitter();
        this.onNewMessage = new core_1.EventEmitter();
        this.onParticipantJoined = new core_1.EventEmitter();
        this.onParticipantLeft = new core_1.EventEmitter();
        this.onRoomClosed = new core_1.EventEmitter();
        // New Output
        this.onParticipantEvicted = new core_1.EventEmitter();
        this.onParticipantPublished = new core_1.EventEmitter();
        this.onStreamAdded = new core_1.EventEmitter();
        this.onStreamRemoved = new core_1.EventEmitter();
        this.onUpdateMainSpeaker = new core_1.EventEmitter();
        this.onCustomNotification = new core_1.EventEmitter();
        this.onServerConnected = new core_1.EventEmitter();
        this.onErrorServer = new core_1.EventEmitter();
        this.onCameraAccessChange = new core_1.EventEmitter();
        // Dictionary of Subscribers
        this.participants = new Map();
        // Array of all streams
        this.streams = new Map();
        this.myCameraId = null;
        // Flags
        this.connectedToServer = false;
    }
    OpenViduDirective.prototype.ngOnDestroy = function () {
        this.leaveRoom();
    };
    // Listen for changes in variables
    OpenViduDirective.prototype.ngOnChanges = function () {
        // Check if we have all of the required params
        if (this.wsUrl && this.sessionId && this.participantId) {
            // Connect to server
            this.openvidu = new openvidu_browser_1.OpenVidu(this.wsUrl);
            if (this.apiKey) {
                this.session = this.openvidu.initSession(this.apiKey, this.sessionId);
            }
            else {
                this.session = this.openvidu.initSession(this.sessionId);
            }
            /*if (error) {
                // Emit event
                this.onErrorServer.emit({
                    error: error
                });
                return console.log(error);
            }*/
            // Start listening for events
            this.setListeners();
            // Set flag
            this.connectedToServer = true;
            // Emit event
            this.onServerConnected.emit();
            // [Debug]
            console.log(this.openvidu);
            // Connect to Room
            this.joinRoom();
        }
    };
    Object.defineProperty(OpenViduDirective.prototype, "micEnabled", {
        get: function () {
            return (this.myCamera && this.myCamera.getWebRtcPeer() && this.myCamera.getWebRtcPeer().audioEnabled);
        },
        set: function (enabled) {
            this.myCamera.getWebRtcPeer().audioEnabled = enabled;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OpenViduDirective.prototype, "camEnabled", {
        get: function () {
            return (this.myCamera && this.myCamera.getWebRtcPeer() && this.myCamera.getWebRtcPeer().videoEnabled);
        },
        set: function (enabled) {
            this.myCamera.getWebRtcPeer().videoEnabled = enabled;
        },
        enumerable: true,
        configurable: true
    });
    OpenViduDirective.prototype.sendMessage = function (text) {
        this.openvidu.openVidu.sendMessage(this.sessionId, this.getCurrentToken(), text);
    };
    OpenViduDirective.prototype.sendCustomNotification = function (obj, callback) {
        this.openvidu.openVidu.sendCustomRequest(obj, callback);
    };
    /**
     * Set new camera device for current user.
     * @param deviceId - if null the camera is the default one
     */
    OpenViduDirective.prototype.setCamera = function (deviceId) {
        var _this = this;
        // Set camera options
        var cameraOptions = null;
        if (deviceId === null) {
            cameraOptions = {
                recvAudio: true,
                recvVideo: true,
                audio: true,
                video: true,
                data: true,
                mediaConstraints: {
                    audio: true,
                    video: { width: { ideal: 1280 } }
                }
            };
        }
        else {
            cameraOptions = {
                recvAudio: true,
                recvVideo: true,
                audio: { deviceId: { exact: deviceId } },
                video: { deviceId: { exact: deviceId } },
                data: true,
                mediaConstraints: {
                    audio: true,
                    video: { width: { ideal: 1280 } }
                }
            };
        }
        // Create stream with the options
        var camera = this.openvidu.openVidu.getCamera(cameraOptions);
        // Show camera
        camera.requestCameraAccess(function (error, camera) {
            // User didn't allow access
            if (error) {
                _this.onCameraAccessChange.emit({
                    access: false,
                    error: error
                });
                return console.log(error);
            }
            console.log('CAMERA CHANGED TO: ' + deviceId);
            _this.myCameraId = deviceId;
            // User wants to change camera
            if (deviceId !== null) {
                // Ugly fix: leave room and re-enter
                _this.openvidu.openVidu.close(false);
                _this.joinRoom(false);
                return;
            }
            // Fix: manually emit event
            _this.onRoomConnected.emit({
                session: _this.session
            });
            // Set myCamera
            _this.myCamera = camera;
            _this.myCamera.mirrorLocalStream(_this.myCamera.getWrStream());
            // By default, current user is main speaker
            _this.mainStream = _this.myCamera;
            _this.streams.set(_this.myCamera.getId(), _this.myCamera);
            _this.participants.set(_this.myCamera.getParticipant().getId(), _this.myCamera.getParticipant());
            // Publish new camera
            _this.myCamera.isReady = true;
            _this.myCamera.publish();
            // [Debug]
            var allStreams = _this.session.connection.getStreams();
            console.log('MY CAMERA APPROVED: ', camera);
            console.log('All streams: ', allStreams);
            // Emit event
            _this.onUpdateMainSpeaker.emit({
                stream: _this.mainStream
            });
            // Emit event
            _this.onCameraAccessChange.emit({
                access: true,
                camera: camera
            });
        });
    };
    OpenViduDirective.prototype.leaveRoom = function () {
        if (this.connectedToServer) {
            // Emit event
            this.onLeaveRoom.emit();
        }
        // Reset
        if (this.openvidu) {
            this.openvidu.openVidu.close(!this.connectedToServer);
        }
        this.session = null;
        this.participants = new Map();
        this.streams = new Map();
        this.mainStream = null;
        this.connectedToServer = false;
    };
    OpenViduDirective.prototype.joinRoom = function (setCamera) {
        var _this = this;
        // Check that we are connected
        if (!this.connectedToServer) {
            this.onErrorRoom.emit({
                error: new Error('Not connected to server yet')
            });
            return;
        }
        // Set attributes
        var token = this.getCurrentToken();
        var participantData = {
            username: this.participantId
        };
        // Enter session
        this.session.connect(token, JSON.stringify(participantData), function (error) {
            if (error) {
                if (typeof error === 'string') {
                    error = new Error(error);
                }
                // Emit event
                _this.onErrorRoom.emit({
                    error: error
                });
                return console.log(error);
            }
            if (setCamera !== false) {
                _this.setCamera(_this.myCameraId);
            }
        });
    };
    OpenViduDirective.prototype.setListeners = function () {
        var _this = this;
        // Set listeners
        this.session.on('update-main-speaker', function (streamEvent) {
            console.warn('update-main-speaker');
            // [PR] make a fix in Openvidu ? PR #2
            // "participantId" is not a participant ID, is a stream ID
            var mainStream = _this.streams.get(streamEvent.participantId);
            if (mainStream) {
                // Check participant if it exists
                if (!_this.participants.has(mainStream.getParticipant().getId())) {
                    _this.participants.set(mainStream.getParticipant().getId(), mainStream.getParticipant());
                }
                // Set main speaker
                _this.mainStream = mainStream;
                // Emit event
                _this.onUpdateMainSpeaker.emit({
                    stream: mainStream
                });
            }
        });
        this.session.on('room-connected', function () {
            console.warn('room-connected');
            // Emit event
            _this.onRoomConnected.emit();
        });
        this.session.on('error-room', function (errorEvent) {
            console.warn('error-room');
            // Emit event
            _this.onErrorRoom.emit({
                error: errorEvent
            });
        });
        this.session.on('participant-published', function (participantEvent) {
            console.warn('participant-published');
            // Emit event
            _this.onParticipantPublished.emit({
                participant: participantEvent.participant
            });
        });
        this.session.on('participant-joined', function (participantEvent) {
            console.warn('participant-joined');
            console.log(participantEvent.connection);
            var newParticipant = participantEvent.connection;
            _this.participants.set(newParticipant.getId(), newParticipant);
            // Emit event
            _this.onParticipantJoined.emit({
                participant: newParticipant
            });
        });
        this.session.on('participant-left', function (participantEvent) {
            console.warn('participant-left');
            // Remove from  array
            var oldParticipant = participantEvent.connection;
            _this.participants.delete(oldParticipant.getId());
            console.log(_this.mainStream);
            console.log(oldParticipant);
            // Manually update main speaker if it was the main speaker
            if (_this.mainStream === null ||
                (_this.mainStream !== null && _this.mainStream.getParticipant().getId() === oldParticipant.getId())) {
                // Update main speaker locally
                _this.autoUpdateMainSpeaker();
            }
            // Emit event
            _this.onParticipantLeft.emit({
                participant: oldParticipant
            });
        });
        this.session.on('participant-evicted', function (participantEvent) {
            console.warn('participant-evicted');
            // Emit event
            _this.onParticipantEvicted.emit({
                participant: participantEvent.participant
            });
        });
        this.session.on('stream-added', function (streamEvent) {
            console.warn('stream-added');
            // Subscribe to be able to receive stream
            var newStream = streamEvent.stream;
            newStream.subscribe();
            _this.streams.set(newStream.getId(), newStream);
            // Also add to participant
            if (!_this.participants.has(newStream.getParticipant().getId())) {
                _this.participants.set(newStream.getParticipant().getId(), newStream.getParticipant());
            }
            _this.participants.get(newStream.getParticipant().getId()).addStream(newStream);
            // Consensus: Update main speaker by new participant
            _this.updateMainSpeakerManually(newStream);
            // Emit event
            _this.onStreamAdded.emit({
                stream: newStream
            });
        });
        this.session.on('stream-removed', function (streamEvent) {
            console.warn('stream-removed');
            // Remove from array
            var oldStream = streamEvent.stream;
            _this.streams.delete(oldStream.getId());
            // TODO: remove from participant
            // Manually update main speaker if it was the main speaker
            if (_this.mainStream === null ||
                (_this.mainStream !== null && _this.mainStream.getId() === oldStream.getId())) {
                // Update main speaker locally
                _this.autoUpdateMainSpeaker();
            }
            // Emit event
            _this.onStreamRemoved.emit({
                stream: oldStream
            });
        });
        this.session.on('newMessage', function (messageEvent) {
            console.warn('new-message');
            // Emit event
            _this.onNewMessage.emit({
                session: _this.session,
                participant: _this.participants.get(messageEvent.user),
                message: messageEvent.message
            });
        });
        this.session.on('room-closed', function () {
            console.warn('room-closed');
            // Emit event
            _this.onRoomClosed.emit();
        });
        this.session.on('lost-connection', function () {
            console.warn('lost-connection');
            // Emit event
            _this.onLostConnection.emit();
        });
        this.session.on('error-media', function (errorEvent) {
            console.warn('error-media');
            // Emit event
            _this.onErrorMedia.emit({
                error: errorEvent.error
            });
        });
        this.session.on('custom-message-received', function (customNotificationEvent) {
            console.warn('error-media');
            // Emit event
            _this.onCustomNotification.emit(customNotificationEvent.params);
        });
    };
    /**
     * Update main speaker based on a established consensus
     */
    OpenViduDirective.prototype.autoUpdateMainSpeaker = function () {
        // Consensus: choose next speaker based on participantId
        var firstParticipant = null;
        for (var key in this.participants) {
            if (firstParticipant === null || this.participants.get(key).getId() < firstParticipant.getId()) {
                firstParticipant = this.participants.get(key);
            }
        }
        if (firstParticipant) {
            // Get his stream
            var firstStream = firstParticipant.getStreams()[Object.keys(firstParticipant.getStreams())[0]];
            // Set new main speaker
            this.mainStream = firstStream;
            // Emit event
            this.onUpdateMainSpeaker.emit({
                stream: firstStream
            });
        }
    };
    /**
     * Update main speaker and emit event
     */
    OpenViduDirective.prototype.updateMainSpeakerManually = function (stream) {
        this.mainStream = stream;
        // Emit event
        this.onUpdateMainSpeaker.emit({
            stream: stream
        });
    };
    /**
     * Get current token to connect to OpenVidu server
     */
    OpenViduDirective.prototype.getCurrentToken = function () {
        return (this.token)
            ? this.token
            : 'dummytoken' + this.participantId;
    };
    return OpenViduDirective;
}());
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduDirective.prototype, "wsUrl", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduDirective.prototype, "sessionId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduDirective.prototype, "participantId", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduDirective.prototype, "apiKey", void 0);
__decorate([
    core_1.Input(),
    __metadata("design:type", String)
], OpenViduDirective.prototype, "token", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onRoomConnected", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onErrorRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onLeaveRoom", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onErrorMedia", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onLostConnection", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onNewMessage", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onParticipantJoined", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onParticipantLeft", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onRoomClosed", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onParticipantEvicted", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onParticipantPublished", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onStreamAdded", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onStreamRemoved", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onUpdateMainSpeaker", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onCustomNotification", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onServerConnected", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onErrorServer", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], OpenViduDirective.prototype, "onCameraAccessChange", void 0);
OpenViduDirective = __decorate([
    core_1.Directive({
        selector: 'openvidu-template, [openvidu-template]',
        exportAs: 'openviduApi'
    })
], OpenViduDirective);
exports.OpenViduDirective = OpenViduDirective;
